
#include "pmu-events/pmu-events.h"
#include "util/header.h"
#include "util/pmu.h"
#include <string.h>
#include <stddef.h>

struct compact_pmu_event {
  int offset;
};

static const char *const big_c_string =
/* offset=0 */ "CPI\000\000\0001 / IPC\000\000\000\000\000\000"
/* offset=19 */ "DCache_L2_All\000\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000"
/* offset=80 */ "DCache_L2_All_Hits\000\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000"
/* offset=171 */ "DCache_L2_All_Miss\000\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000"
/* offset=302 */ "DCache_L2_Hits\000\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000"
/* offset=367 */ "DCache_L2_Misses\000\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000"
/* offset=434 */ "Frontend_Bound_SMT\000\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000"
/* offset=597 */ "IPC\000group1\000\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000"
/* offset=657 */ "L1D_Cache_Fill_BW\000\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000"
/* offset=725 */ "M1\000\000\000ipc + M2\000\000\000\000\000\000"
/* offset=744 */ "M2\000\000\000ipc + M1\000\000\000\000\000\000"
/* offset=763 */ "M3\000\000\0001 / M3\000\000\000\000\000\000"
/* offset=780 */ "aes_blocked_cycles\000cpum_cf\000crypto6\000AES Blocked Cycle Count. Unit: cpum_cf \000event=0x4f\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=1054 */ "aes_blocked_cycles\000cpum_cf\000crypto\000AES Blocked Cycle Count. Unit: cpum_cf \000event=0x4f\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=1327 */ "aes_blocked_functions\000cpum_cf\000crypto6\000AES Blocked Function Count. Unit: cpum_cf \000event=0x4e\000\000\000\000\000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=1609 */ "aes_blocked_functions\000cpum_cf\000crypto\000AES Blocked Function Count. Unit: cpum_cf \000event=0x4e\000\000\000\000\000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=1890 */ "aes_cycles\000cpum_cf\000crypto6\000AES Cycle Count. Unit: cpum_cf \000event=0x4d\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000"
/* offset=2100 */ "aes_cycles\000cpum_cf\000crypto\000AES Cycle Count. Unit: cpum_cf \000event=0x4d\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000"
/* offset=2309 */ "aes_functions\000cpum_cf\000crypto6\000AES Function Count. Unit: cpum_cf \000event=0x4c\000\000\000\000\000\000This counter counts the total number of the AES functions issued by the CPU\000"
/* offset=2466 */ "aes_functions\000cpum_cf\000crypto\000AES Function Count. Unit: cpum_cf \000event=0x4c\000\000\000\000\000\000This counter counts the total number of the AES functions issued by the CPU\000"
/* offset=2622 */ "bcd_dfp_execution_slots\000cpum_cf\000extended\000BCD DFP Execution Slots. Unit: cpum_cf \000event=0xe0\000\000\000\000\000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000"
/* offset=2874 */ "bcd_dfp_execution_slots\000cpum_cf\000extended\000Binary Coded Decimal to Decimal Floating Point conversions. Unit: cpum_cf \000event=0xe0\000\000\000\000\000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000"
/* offset=3161 */ "bp_l1_btb_correct\000\000branch\000L1 BTB Correction\000event=0x8a\000\000\000\000\000\000\000"
/* offset=3222 */ "bp_l2_btb_correct\000\000branch\000L2 BTB Correction\000event=0x8b\000\000\000\000\000\000\000"
/* offset=3283 */ "cache_miss_cycles\000group1\000\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000"
/* offset=3351 */ "cpu_cycles\000cpum_cf\000basic\000Cycle Count. Unit: cpum_cf \000event=0\000\000\000\000\000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000"
/* offset=3535 */ "crste_1mb_writes\000cpum_cf\000extended\000One Megabyte CRSTE writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page\000"
/* offset=3757 */ "crypto_all\000pai_crypto\000pai_crypto\000CRYPTO ALL. Unit: pai_crypto \000event=0x1000\000\000\000\000\000\000Sums of all non zero cryptography counters\000"
/* offset=3881 */ "dcache_miss_cpi\000\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000"
/* offset=3942 */ "dcw_off_drawer\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Off-Drawer Cache. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache\000"
/* offset=4192 */ "dcw_off_drawer_memory\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Off-Drawer Memory. Unit: cpum_cf \000event=0x9f\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=4440 */ "dcw_on_chip\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Cache. Unit: cpum_cf \000event=0x95\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache\000"
/* offset=4681 */ "dcw_on_chip_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Cache with Chip HP Hit. Unit: cpum_cf \000event=0x97\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache after using chip level horizontal persistence, Chip-HP hit\000"
/* offset=5007 */ "dcw_on_chip_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Cache with Drawer HP Hit. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=5335 */ "dcw_on_chip_iv\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Cache with Intervention. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache with intervention\000"
/* offset=5615 */ "dcw_on_chip_memory\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Memory. Unit: cpum_cf \000event=0x9c\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=5854 */ "dcw_on_drawer\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Drawer Cache. Unit: cpum_cf \000event=0x9a\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache\000"
/* offset=6101 */ "dcw_on_drawer_memory\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Drawer Memory. Unit: cpum_cf \000event=0x9e\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=6346 */ "dcw_on_module\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Module Cache. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Module Level-2 cache\000"
/* offset=6593 */ "dcw_on_module_memory\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Module Memory. Unit: cpum_cf \000event=0x9d\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Module memory\000"
/* offset=6838 */ "dcw_req\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Cache. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache\000"
/* offset=7074 */ "dcw_req_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Cache with Chip HP Hit. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache after using chip level horizontal persistence, Chip-HP hit\000"
/* offset=7395 */ "dcw_req_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Cache with Drawer HP Hit. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache after using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=7724 */ "dcw_req_iv\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Cache with Intervention. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache with intervention\000"
/* offset=7999 */ "dea_blocked_cycles\000cpum_cf\000crypto6\000DEA Blocked Cycle Count. Unit: cpum_cf \000event=0x4b\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=8273 */ "dea_blocked_cycles\000cpum_cf\000crypto\000DEA Blocked Cycle Count. Unit: cpum_cf \000event=0x4b\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=8546 */ "dea_blocked_functions\000cpum_cf\000crypto6\000DEA Blocked Function Count. Unit: cpum_cf \000event=0x4a\000\000\000\000\000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=8828 */ "dea_blocked_functions\000cpum_cf\000crypto\000DEA Blocked Function Count. Unit: cpum_cf \000event=0x4a\000\000\000\000\000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=9109 */ "dea_cycles\000cpum_cf\000crypto6\000DEA Cycle Count. Unit: cpum_cf \000event=0x49\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000"
/* offset=9319 */ "dea_cycles\000cpum_cf\000crypto\000DEA Cycle Count. Unit: cpum_cf \000event=0x49\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000"
/* offset=9528 */ "dea_functions\000cpum_cf\000crypto6\000DEA Function Count. Unit: cpum_cf \000event=0x48\000\000\000\000\000\000This counter counts the total number of the DEA functions issued by the CPU\000"
/* offset=9685 */ "dea_functions\000cpum_cf\000crypto\000DEA Function Count. Unit: cpum_cf \000event=0x48\000\000\000\000\000\000This counter counts the total number of the DEA functions issued by the CPU\000"
/* offset=9841 */ "decimal_instructions\000cpum_cf\000extended\000Decimal Instructions. Unit: cpum_cf \000event=0xe2\000\000\000\000\000\000Decimal instructions dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000"
/* offset=10028 */ "decimal_instructions\000cpum_cf\000extended\000Decimal instruction dispatched. Unit: cpum_cf \000event=0xe2\000\000\000\000\000\000Decimal instruction dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000"
/* offset=10224 */ "dflt_access\000cpum_cf\000extended\000Cycles CPU spent obtaining access to Deflate unit. Unit: cpum_cf \000event=0xf7\000\000\000\000\000\000Cycles CPU spent obtaining access to Deflate unit\000"
/* offset=10385 */ "dflt_access\000cpum_cf\000extended\000Cycles CPU spent obtaining access to Deflate unit. Unit: cpum_cf \000event=0xf8\000\000\000\000\000\000Cycles CPU spent obtaining access to Deflate unit\000"
/* offset=10546 */ "dflt_cc\000cpum_cf\000extended\000Increments DEFLATE CONVERSION CALL. Unit: cpum_cf \000event=0x108\000\000\000\000\000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed\000"
/* offset=10712 */ "dflt_cc\000cpum_cf\000extended\000Increments DEFLATE CONVERSION CALL. Unit: cpum_cf \000event=0x109\000\000\000\000\000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed\000"
/* offset=10878 */ "dflt_ccfinish\000cpum_cf\000extended\000Increments completed DEFLATE CONVERSION CALL. Unit: cpum_cf \000event=0x109\000\000\000\000\000\000 Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2 complete\000"
/* offset=11110 */ "dflt_ccfinish\000cpum_cf\000extended\000Increments completed DEFLATE CONVERSION CALL. Unit: cpum_cf \000event=0x10a\000\000\000\000\000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2\000"
/* offset=11332 */ "dflt_cycles\000cpum_cf\000extended\000Cycles CPU is using Deflate unit. Unit: cpum_cf \000event=0xfc\000\000\000\000\000\000Cycles CPU is using Deflate unit\000"
/* offset=11459 */ "dflt_cycles\000cpum_cf\000extended\000Cycles CPU is using Deflate unit. Unit: cpum_cf \000event=0xfd\000\000\000\000\000\000Cycles CPU is using Deflate unit\000"
/* offset=11586 */ "dispatch_blocked.any\000\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=0x9,period=200000,umask=0x20\000\000\000\000\000\000\000"
/* offset=11720 */ "dtlb1_gpage_writes\000cpum_cf\000extended\000DTLB1 Two-Gigabyte Page Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a two-gigabyte page\000"
/* offset=11929 */ "dtlb1_hpage_writes\000cpum_cf\000extended\000DTLB1 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000"
/* offset=12138 */ "dtlb1_hpage_writes\000cpum_cf\000extended\000DTLB1 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000"
/* offset=12347 */ "dtlb1_hpage_writes\000cpum_cf\000extended\000DTLB1 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000"
/* offset=12556 */ "dtlb1_misses\000cpum_cf\000extended\000DTLB1 Misses. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000"
/* offset=12729 */ "dtlb1_misses\000cpum_cf\000extended\000DTLB1 Misses. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000"
/* offset=12902 */ "dtlb1_misses\000cpum_cf\000extended\000DTLB1 Misses. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle an DTLB1 miss is in progress\000"
/* offset=13076 */ "dtlb1_writes\000cpum_cf\000extended\000DTLB1 Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000"
/* offset=13245 */ "dtlb1_writes\000cpum_cf\000extended\000DTLB1 Writes. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000"
/* offset=13414 */ "dtlb1_writes\000cpum_cf\000extended\000DTLB1 Writes. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000"
/* offset=13583 */ "dtlb1_writes\000cpum_cf\000extended\000DTLB1 Writes. Unit: cpum_cf \000event=0x90\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000"
/* offset=13752 */ "dtlb2_gpage_writes\000cpum_cf\000extended\000DTLB2 Two-Gigabyte Page Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A translation entry for a two-gigabyte page was written into the Level-2 TLB\000"
/* offset=13928 */ "dtlb2_hpage_writes\000cpum_cf\000extended\000DTLB2 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page or a Last Host Translation was done\000"
/* offset=14193 */ "dtlb2_hpage_writes\000cpum_cf\000extended\000DTLB2 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page\000"
/* offset=14422 */ "dtlb2_misses\000cpum_cf\000extended\000DTLB2 Misses. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the Level-1 Data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on z13 and prior machines\000"
/* offset=14746 */ "dtlb2_misses\000cpum_cf\000extended\000DTLB2 Misses. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on prior machines\000"
/* offset=15054 */ "dtlb2_writes\000cpum_cf\000extended\000DTLB2 Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the Level-1 Data cache. This is a replacement for what was provided for the DTLB on z13 and prior machines\000"
/* offset=15342 */ "dtlb2_writes\000cpum_cf\000extended\000DTLB2 Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the data cache. This is a replacement for what was provided for the DTLB on prior machines\000"
/* offset=15614 */ "ecc_blocked_cycles_count\000cpum_cf\000crypto6\000ECC Blocked Cycles Count. Unit: cpum_cf \000event=0x53\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the elliptic-curve cryptography (ECC) functions issued by the CPU because the ECC coprocessor is busy performing a function issued by another CPU\000"
/* offset=15921 */ "ecc_blocked_function_count\000cpum_cf\000crypto6\000Ecc Blocked Function Count. Unit: cpum_cf \000event=0x52\000\000\000\000\000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions that are issued by the CPU and are blocked because the ECC coprocessor is busy performing a function issued by another CPU\000"
/* offset=16234 */ "ecc_cycles_count\000cpum_cf\000crypto6\000ECC Cycles Count. Unit: cpum_cf \000event=0x51\000\000\000\000\000\000This counter counts the total number of CPU cycles when the ECC coprocessor is busy performing the elliptic-curve cryptography (ECC) functions issued by the CPU\000"
/* offset=16477 */ "ecc_function_count\000cpum_cf\000crypto6\000ECC Function Count. Unit: cpum_cf \000event=0x50\000\000\000\000\000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions issued by the CPU\000"
/* offset=16669 */ "eist_trans\000\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000,umask=0x0\000\000\000\000\000\000\000"
/* offset=16796 */ "event-hyphen\000uncore_cbox\000uncore\000UNC_CBO_HYPHEN. Unit: uncore_cbox \000event=0xe0,umask=0x00\000\000\000\000\000\000UNC_CBO_HYPHEN\000"
/* offset=16905 */ "event-two-hyph\000uncore_cbox\000uncore\000UNC_CBO_TWO_HYPH. Unit: uncore_cbox \000event=0xc0,umask=0x00\000\000\000\000\000\000UNC_CBO_TWO_HYPH\000"
/* offset=17020 */ "ibm_reserved_155\000pai_crypto\000pai_crypto\000IBM RESERVED_155. Unit: pai_crypto \000event=0x109b\000\000\000\000\000\000Reserved for IBM use\000"
/* offset=17134 */ "ibm_reserved_156\000pai_crypto\000pai_crypto\000IBM RESERVED_156. Unit: pai_crypto \000event=0x109c\000\000\000\000\000\000Reserved for IBM use\000"
/* offset=17248 */ "icache_miss_cycles\000\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000"
/* offset=17312 */ "icw_off_drawer\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Off-Drawer Cache. Unit: cpum_cf \000event=0xb3\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an Off-Drawer Level-2 cache\000"
/* offset=17571 */ "icw_off_drawer_memory\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Off-Drawer Memory. Unit: cpum_cf \000event=0xb7\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=17833 */ "icw_on_chip\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Cache. Unit: cpum_cf \000event=0xad\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache\000"
/* offset=18088 */ "icw_on_chip_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Cache with Chip HP Hit. Unit: cpum_cf \000event=0xaf\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using chip level horizontal persistence, Chip-HP hit\000"
/* offset=18422 */ "icw_on_chip_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Cache with Drawer HP Hit. Unit: cpum_cf \000event=0xb0\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip level 2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=18764 */ "icw_on_chip_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Cache with Intervention. Unit: cpum_cf \000event=0xae\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Chip Level-2 cache with intervention\000"
/* offset=19053 */ "icw_on_chip_memory\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Memory. Unit: cpum_cf \000event=0xb4\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=19306 */ "icw_on_drawer\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Drawer Cache. Unit: cpum_cf \000event=0xb2\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Drawer Level-2 cache\000"
/* offset=19562 */ "icw_on_drawer_memory\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Drawer Memory. Unit: cpum_cf \000event=0xb6\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=19821 */ "icw_on_module\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Module Cache. Unit: cpum_cf \000event=0xb1\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache\000"
/* offset=20082 */ "icw_on_module_memory\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Module Memory. Unit: cpum_cf \000event=0xb5\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Module memory\000"
/* offset=20341 */ "icw_req\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Cache. Unit: cpum_cf \000event=0xa9\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced the requestors Level-2 cache\000"
/* offset=20583 */ "icw_req_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Cache with Chip HP Hit. Unit: cpum_cf \000event=0xab\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache using chip level horizontal persistence, Chip-HP hit\000"
/* offset=20909 */ "icw_req_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Cache with Drawer HP Hit. Unit: cpum_cf \000event=0xac\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestor’s Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=21246 */ "icw_req_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Cache with Intervention. Unit: cpum_cf \000event=0xaa\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache with intervention\000"
/* offset=21532 */ "idcw_off_drawer_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer Cache with Chip Hit. Unit: cpum_cf \000event=0xa7\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit\000"
/* offset=21898 */ "idcw_off_drawer_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer Cache with Drawer Hit. Unit: cpum_cf \000event=0xa8\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=22272 */ "idcw_off_drawer_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer Cache with Intervention. Unit: cpum_cf \000event=0xa6\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache with intervention\000"
/* offset=22601 */ "idcw_on_drawer_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer Cache with Chip Hit. Unit: cpum_cf \000event=0xa4\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit\000"
/* offset=22964 */ "idcw_on_drawer_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer Cache with Drawer Hit. Unit: cpum_cf \000event=0xa5\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=23335 */ "idcw_on_drawer_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer Cache with Intervention. Unit: cpum_cf \000event=0xa3\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache with intervention\000"
/* offset=23661 */ "idcw_on_module_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory Cache with Chip Hit. Unit: cpum_cf \000event=0xa1\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using chip horizontal persistence, Chip-HP hit\000"
/* offset=24025 */ "idcw_on_module_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory Cache with Drawer Hit. Unit: cpum_cf \000event=0xa2\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=24403 */ "idcw_on_module_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory Cache with Intervention. Unit: cpum_cf \000event=0xa0\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache with intervention\000"
/* offset=24736 */ "instructions\000cpum_cf\000basic\000Instruction Count. Unit: cpum_cf \000event=0x1\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU\000"
/* offset=24885 */ "itlb1_misses\000cpum_cf\000extended\000ITLB1 Misses. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress\000"
/* offset=25065 */ "itlb1_misses\000cpum_cf\000extended\000ITLB1 Misses. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress\000"
/* offset=25245 */ "itlb1_misses\000cpum_cf\000extended\000ITLB1 Misses. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress\000"
/* offset=25426 */ "itlb1_misses\000cpum_cf\000extended\000ITLB1 Misses. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress\000"
/* offset=25607 */ "itlb1_writes\000cpum_cf\000extended\000ITLB1 Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000"
/* offset=25783 */ "itlb1_writes\000cpum_cf\000extended\000ITLB1 Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000A translation entry has been written into the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000"
/* offset=25961 */ "itlb1_writes\000cpum_cf\000extended\000ITLB1 Writes. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000"
/* offset=26137 */ "itlb1_writes\000cpum_cf\000extended\000ITLB1 Writes. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000"
/* offset=26313 */ "itlb2_misses\000cpum_cf\000extended\000ITLB2 Misses. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the Level-1 Instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on z13 and prior machines\000"
/* offset=26648 */ "itlb2_misses\000cpum_cf\000extended\000ITLB2 Misses. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on prior machines\000"
/* offset=26967 */ "itlb2_writes\000cpum_cf\000extended\000ITLB2 Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on prior machines\000"
/* offset=27252 */ "itlb2_writes\000cpum_cf\000extended\000ITLB2 Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on z13 and prior machines\000"
/* offset=27545 */ "kdsa_ecdsa_sign_p256\000pai_crypto\000pai_crypto\000KDSA ECDSA SIGN P256. Unit: pai_crypto \000event=0x1084\000\000\000\000\000\000KDSA-ECDSA-Sign-P256 function ending with CC=0\000"
/* offset=27693 */ "kdsa_ecdsa_sign_p384\000pai_crypto\000pai_crypto\000KDSA ECDSA SIGN P384. Unit: pai_crypto \000event=0x1085\000\000\000\000\000\000KDSA-ECDSA-Sign-P384 function ending with CC=0\000"
/* offset=27841 */ "kdsa_ecdsa_sign_p521\000pai_crypto\000pai_crypto\000KDSA ECDSA SIGN P521. Unit: pai_crypto \000event=0x1086\000\000\000\000\000\000KDSA-ECDSA-Sign-P521 function ending with CC=0\000"
/* offset=27989 */ "kdsa_ecdsa_verify_p256\000pai_crypto\000pai_crypto\000KDSA ECDSA VERIFY P256. Unit: pai_crypto \000event=0x1081\000\000\000\000\000\000KDSA-ECDSA-Verify-P256 function ending with CC=0 or CC=2\000"
/* offset=28151 */ "kdsa_ecdsa_verify_p384\000pai_crypto\000pai_crypto\000KDSA ECDSA VERIFY P384. Unit: pai_crypto \000event=0x1082\000\000\000\000\000\000KDSA-ECDSA-Verify-P384 function ending with CC=0 or CC=2\000"
/* offset=28313 */ "kdsa_ecdsa_verify_p521\000pai_crypto\000pai_crypto\000KDSA ECDSA VERIFY P521. Unit: pai_crypto \000event=0x1083\000\000\000\000\000\000KDSA-ECDSA-Verify-P521 function ending with CC=0 or CC=2\000"
/* offset=28475 */ "kdsa_eddsa_sign_ed25519\000pai_crypto\000pai_crypto\000KDSA EDDSA SIGN ED25519. Unit: pai_crypto \000event=0x108c\000\000\000\000\000\000KDSA-EdDSA-Sign-Ed25519 function ending with CC=0\000"
/* offset=28632 */ "kdsa_eddsa_sign_ed448\000pai_crypto\000pai_crypto\000KDSA EDDSA SIGN ED448. Unit: pai_crypto \000event=0x108d\000\000\000\000\000\000KDSA-EdDSA-Sign-Ed448 function ending with CC=0\000"
/* offset=28783 */ "kdsa_eddsa_verify_ed25519\000pai_crypto\000pai_crypto\000KDSA EDDSA VERIFY ED25519. Unit: pai_crypto \000event=0x108a\000\000\000\000\000\000KDSA-EdDSA-Verify-Ed25519 function ending with CC=0 or CC=2\000"
/* offset=28954 */ "kdsa_eddsa_verify_ed448\000pai_crypto\000pai_crypto\000KDSA EDDSA VERIFY ED448. Unit: pai_crypto \000event=0x108b\000\000\000\000\000\000KDSA-EdDSA-Verify-Ed448 function ending with CC=0 or CC=2\000"
/* offset=29119 */ "kdsa_encrypted_ecdsa_sign_p256\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P256. Unit: pai_crypto \000event=0x1087\000\000\000\000\000\000KDSA-Encrypted-ECDSA-Sign-P256 function ending with CC=0\000"
/* offset=29297 */ "kdsa_encrypted_ecdsa_sign_p384\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P384. Unit: pai_crypto \000event=0x1088\000\000\000\000\000\000KDSA-Encrypted-ECDSA-Sign-P384 function ending with CC=0\000"
/* offset=29475 */ "kdsa_encrypted_ecdsa_sign_p521\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P521. Unit: pai_crypto \000event=0x1089\000\000\000\000\000\000KDSA-Encrypted-ECDSA-Sign-P521 function ending with CC=0\000"
/* offset=29653 */ "kdsa_encrypted_eddsa_sign_ed25519\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED EDDSA SIGN ED25519. Unit: pai_crypto \000event=0x108e\000\000\000\000\000\000KDSA-Encrypted-EdDSA-Sign-Ed25519 function ending with CC=0\000"
/* offset=29840 */ "kdsa_encrypted_eddsa_sign_ed448\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED EDDSA SIGN ED448. Unit: pai_crypto \000event=0x108f\000\000\000\000\000\000KDSA-Encrypted-EdDSA-Sign-Ed448 function ending with CC=0\000"
/* offset=30021 */ "kimd_ghash\000pai_crypto\000pai_crypto\000KIMD GHASH. Unit: pai_crypto \000event=0x1051\000\000\000\000\000\000KIMD-GHASH function ending with CC=0\000"
/* offset=30139 */ "kimd_sha3_224\000pai_crypto\000pai_crypto\000KIMD SHA3 224. Unit: pai_crypto \000event=0x104b\000\000\000\000\000\000KIMD-SHA3-224 function ending with CC=0\000"
/* offset=30266 */ "kimd_sha3_256\000pai_crypto\000pai_crypto\000KIMD SHA3 256. Unit: pai_crypto \000event=0x104c\000\000\000\000\000\000KIMD-SHA3-256 function ending with CC=0\000"
/* offset=30393 */ "kimd_sha3_384\000pai_crypto\000pai_crypto\000KIMD SHA3 384. Unit: pai_crypto \000event=0x104d\000\000\000\000\000\000KIMD-SHA3-384 function ending with CC=0\000"
/* offset=30520 */ "kimd_sha3_512\000pai_crypto\000pai_crypto\000KIMD SHA3 512. Unit: pai_crypto \000event=0x104e\000\000\000\000\000\000KIMD-SHA3-512 function ending with CC=0\000"
/* offset=30647 */ "kimd_sha_1\000pai_crypto\000pai_crypto\000KIMD SHA 1. Unit: pai_crypto \000event=0x1048\000\000\000\000\000\000KIMD-SHA-1 function ending with CC=0\000"
/* offset=30765 */ "kimd_sha_256\000pai_crypto\000pai_crypto\000KIMD SHA 256. Unit: pai_crypto \000event=0x1049\000\000\000\000\000\000KIMD-SHA-256 function ending with CC=0\000"
/* offset=30889 */ "kimd_sha_512\000pai_crypto\000pai_crypto\000KIMD SHA 512. Unit: pai_crypto \000event=0x104a\000\000\000\000\000\000KIMD-SHA-512 function ending with CC=0\000"
/* offset=31013 */ "kimd_shake_128\000pai_crypto\000pai_crypto\000KIMD SHAKE 128. Unit: pai_crypto \000event=0x104f\000\000\000\000\000\000KIMD-SHAKE-128 function ending with CC=0\000"
/* offset=31143 */ "kimd_shake_256\000pai_crypto\000pai_crypto\000KIMD SHAKE 256. Unit: pai_crypto \000event=0x1050\000\000\000\000\000\000KIMD-SHAKE-256 function ending with CC=0\000"
/* offset=31273 */ "klmd_sha3_224\000pai_crypto\000pai_crypto\000KLMD SHA3 224. Unit: pai_crypto \000event=0x1055\000\000\000\000\000\000KLMD-SHA3-224 function ending with CC=0\000"
/* offset=31400 */ "klmd_sha3_256\000pai_crypto\000pai_crypto\000KLMD SHA3 256. Unit: pai_crypto \000event=0x1056\000\000\000\000\000\000KLMD-SHA3-256 function ending with CC=0\000"
/* offset=31527 */ "klmd_sha3_384\000pai_crypto\000pai_crypto\000KLMD SHA3 384. Unit: pai_crypto \000event=0x1057\000\000\000\000\000\000KLMD-SHA3-384 function ending with CC=0\000"
/* offset=31654 */ "klmd_sha3_512\000pai_crypto\000pai_crypto\000KLMD SHA3 512. Unit: pai_crypto \000event=0x1058\000\000\000\000\000\000KLMD-SHA3-512 function ending with CC=0\000"
/* offset=31781 */ "klmd_sha_1\000pai_crypto\000pai_crypto\000KLMD SHA 1. Unit: pai_crypto \000event=0x1052\000\000\000\000\000\000KLMD-SHA-1 function ending with CC=0\000"
/* offset=31899 */ "klmd_sha_256\000pai_crypto\000pai_crypto\000KLMD SHA 256. Unit: pai_crypto \000event=0x1053\000\000\000\000\000\000KLMD-SHA-256 function ending with CC=0\000"
/* offset=32023 */ "klmd_sha_512\000pai_crypto\000pai_crypto\000KLMD SHA 512. Unit: pai_crypto \000event=0x1054\000\000\000\000\000\000KLMD-SHA-512 function ending with CC=0\000"
/* offset=32147 */ "klmd_shake_128\000pai_crypto\000pai_crypto\000KLMD SHAKE 128. Unit: pai_crypto \000event=0x1059\000\000\000\000\000\000KLMD-SHAKE-128 function ending with CC=0\000"
/* offset=32277 */ "klmd_shake_256\000pai_crypto\000pai_crypto\000KLMD SHAKE 256. Unit: pai_crypto \000event=0x105a\000\000\000\000\000\000KLMD-SHAKE-256 function ending with CC=0\000"
/* offset=32407 */ "km_aes_128\000pai_crypto\000pai_crypto\000KM AES 128. Unit: pai_crypto \000event=0x1007\000\000\000\000\000\000KM-AES-128 function ending with CC=0\000"
/* offset=32525 */ "km_aes_192\000pai_crypto\000pai_crypto\000KM AES 192. Unit: pai_crypto \000event=0x1008\000\000\000\000\000\000KM-AES-192 function ending with CC=0\000"
/* offset=32643 */ "km_aes_256\000pai_crypto\000pai_crypto\000KM AES 256. Unit: pai_crypto \000event=0x1009\000\000\000\000\000\000KM-AES-256 function ending with CC=0\000"
/* offset=32761 */ "km_dea\000pai_crypto\000pai_crypto\000KM DEA. Unit: pai_crypto \000event=0x1001\000\000\000\000\000\000KM-DEA function ending with CC=0\000"
/* offset=32867 */ "km_encrypted_aes_128\000pai_crypto\000pai_crypto\000KM ENCRYPTED AES 128. Unit: pai_crypto \000event=0x100a\000\000\000\000\000\000KM-Encrypted-AES-128 function ending with CC=0\000"
/* offset=33015 */ "km_encrypted_aes_192\000pai_crypto\000pai_crypto\000KM ENCRYPTED AES 192. Unit: pai_crypto \000event=0x100b\000\000\000\000\000\000KM-Encrypted-AES-192 function ending with CC=0\000"
/* offset=33163 */ "km_encrypted_aes_256\000pai_crypto\000pai_crypto\000KM ENCRYPTED AES 256. Unit: pai_crypto \000event=0x100c\000\000\000\000\000\000KM-Encrypted-AES-256 function ending with CC=0\000"
/* offset=33311 */ "km_encrypted_dea\000pai_crypto\000pai_crypto\000KM ENCRYPTED DEA. Unit: pai_crypto \000event=0x1004\000\000\000\000\000\000KM-Encrypted-DEA function ending with CC=0\000"
/* offset=33447 */ "km_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KM ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1005\000\000\000\000\000\000KM-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=33598 */ "km_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KM ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1006\000\000\000\000\000\000KM-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=33749 */ "km_tdea_128\000pai_crypto\000pai_crypto\000KM TDEA 128. Unit: pai_crypto \000event=0x1002\000\000\000\000\000\000KM-TDEA-128 function ending with CC=0\000"
/* offset=33870 */ "km_tdea_192\000pai_crypto\000pai_crypto\000KM TDEA 192. Unit: pai_crypto \000event=0x1003\000\000\000\000\000\000KM-TDEA-192 function ending with CC=0\000"
/* offset=33991 */ "km_xts_aes_128\000pai_crypto\000pai_crypto\000KM XTS AES 128. Unit: pai_crypto \000event=0x100d\000\000\000\000\000\000KM-XTS-AES-128 function ending with CC=0\000"
/* offset=34121 */ "km_xts_aes_256\000pai_crypto\000pai_crypto\000KM XTS AES 256. Unit: pai_crypto \000event=0x100e\000\000\000\000\000\000KM-XTS-AES-256 function ending with CC=0\000"
/* offset=34251 */ "km_xts_encrypted_aes_128\000pai_crypto\000pai_crypto\000KM XTS ENCRYPTED AES 128. Unit: pai_crypto \000event=0x100f\000\000\000\000\000\000KM-XTS-Encrypted-AES-128 function ending with CC=0\000"
/* offset=34411 */ "km_xts_encrypted_aes_256\000pai_crypto\000pai_crypto\000KM XTS ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1010\000\000\000\000\000\000KM-XTS-Encrypted-AES-256 function ending with CC=0\000"
/* offset=34571 */ "kma_gcm_aes_128\000pai_crypto\000pai_crypto\000KMA GCM AES 128. Unit: pai_crypto \000event=0x101e\000\000\000\000\000\000KMA-GCM-AES-128 function ending with CC=0\000"
/* offset=34704 */ "kma_gcm_aes_192\000pai_crypto\000pai_crypto\000KMA GCM AES 192. Unit: pai_crypto \000event=0x101f\000\000\000\000\000\000KMA-GCM-AES-192 function ending with CC=0\000"
/* offset=34837 */ "kma_gcm_aes_256\000pai_crypto\000pai_crypto\000KMA GCM AES 256. Unit: pai_crypto \000event=0x1020\000\000\000\000\000\000KMA-GCM-AES-256 function ending with CC=0\000"
/* offset=34970 */ "kma_gcm_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMA GCM ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1021\000\000\000\000\000\000KMA-GCM-Encrypted-AES-128 function ending with CC=0\000"
/* offset=35133 */ "kma_gcm_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMA GCM ENCRYPTED AES 192. Unit: pai_crypto \000event=0x1022\000\000\000\000\000\000KMA-GCM-Encrypted-AES-192 function ending with CC=0\000"
/* offset=35296 */ "kma_gcm_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMA GCM ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1023\000\000\000\000\000\000KMA-GCM-Encrypted-AES-256 function ending with CC=0\000"
/* offset=35459 */ "kmac_aes_128\000pai_crypto\000pai_crypto\000KMAC AES 128. Unit: pai_crypto \000event=0x1061\000\000\000\000\000\000KMAC-AES-128 function ending with CC=0\000"
/* offset=35583 */ "kmac_aes_192\000pai_crypto\000pai_crypto\000KMAC AES 192. Unit: pai_crypto \000event=0x1062\000\000\000\000\000\000KMAC-AES-192 function ending with CC=0\000"
/* offset=35707 */ "kmac_aes_256\000pai_crypto\000pai_crypto\000KMAC AES 256. Unit: pai_crypto \000event=0x1063\000\000\000\000\000\000KMAC-AES-256 function ending with CC=0\000"
/* offset=35831 */ "kmac_dea\000pai_crypto\000pai_crypto\000KMAC DEA. Unit: pai_crypto \000event=0x105b\000\000\000\000\000\000KMAC-DEA function ending with CC=0\000"
/* offset=35943 */ "kmac_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1064\000\000\000\000\000\000KMAC-Encrypted-AES-128 function ending with CC=0\000"
/* offset=36097 */ "kmac_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED AES 192. Unit: pai_crypto \000event=0x1065\000\000\000\000\000\000KMAC-Encrypted-AES-192 function ending with CC=0\000"
/* offset=36251 */ "kmac_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1066\000\000\000\000\000\000KMAC-Encrypted-AES-256 function ending with CC=0\000"
/* offset=36405 */ "kmac_encrypted_dea\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED DEA. Unit: pai_crypto \000event=0x105e\000\000\000\000\000\000KMAC-Encrypted-DEA function ending with CC=0\000"
/* offset=36547 */ "kmac_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x105f\000\000\000\000\000\000KMAC-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=36704 */ "kmac_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1060\000\000\000\000\000\000KMAC-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=36861 */ "kmac_tdea_128\000pai_crypto\000pai_crypto\000KMAC TDEA 128. Unit: pai_crypto \000event=0x105c\000\000\000\000\000\000KMAC-TDEA-128 function ending with CC=0\000"
/* offset=36988 */ "kmac_tdea_192\000pai_crypto\000pai_crypto\000KMAC TDEA 192. Unit: pai_crypto \000event=0x105d\000\000\000\000\000\000KMAC-TDEA-192 function ending with CC=0\000"
/* offset=37115 */ "kmc_aes_128\000pai_crypto\000pai_crypto\000KMC AES 128. Unit: pai_crypto \000event=0x1017\000\000\000\000\000\000KMC-AES-128 function ending with CC=0\000"
/* offset=37236 */ "kmc_aes_192\000pai_crypto\000pai_crypto\000KMC AES 192. Unit: pai_crypto \000event=0x1018\000\000\000\000\000\000KMC-AES-192 function ending with CC=0\000"
/* offset=37357 */ "kmc_aes_256\000pai_crypto\000pai_crypto\000KMC AES 256. Unit: pai_crypto \000event=0x1019\000\000\000\000\000\000KMC-AES-256 function ending with CC=0\000"
/* offset=37478 */ "kmc_dea\000pai_crypto\000pai_crypto\000KMC DEA. Unit: pai_crypto \000event=0x1011\000\000\000\000\000\000KMC-DEA function ending with CC=0\000"
/* offset=37587 */ "kmc_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMC ENCRYPTED AES 128. Unit: pai_crypto \000event=0x101a\000\000\000\000\000\000KMC-Encrypted-AES-128 function ending with CC=0\000"
/* offset=37738 */ "kmc_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMC ENCRYPTED AES 192. Unit: pai_crypto \000event=0x101b\000\000\000\000\000\000KMC-Encrypted-AES-192 function ending with CC=0\000"
/* offset=37889 */ "kmc_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMC ENCRYPTED AES 256. Unit: pai_crypto \000event=0x101c\000\000\000\000\000\000KMC-Encrypted-AES-256 function ending with CC=0\000"
/* offset=38040 */ "kmc_encrypted_dea\000pai_crypto\000pai_crypto\000KMC ENCRYPTED DEA. Unit: pai_crypto \000event=0x1014\000\000\000\000\000\000KMC-Encrypted-DEA function ending with CC=0\000"
/* offset=38179 */ "kmc_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMC ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1015\000\000\000\000\000\000KMC-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=38333 */ "kmc_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMC ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1016\000\000\000\000\000\000KMC-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=38487 */ "kmc_prng\000pai_crypto\000pai_crypto\000KMC PRNG. Unit: pai_crypto \000event=0x101d\000\000\000\000\000\000KMC-PRNG function ending with CC=0\000"
/* offset=38599 */ "kmc_tdea_128\000pai_crypto\000pai_crypto\000KMC TDEA 128. Unit: pai_crypto \000event=0x1012\000\000\000\000\000\000KMC-TDEA-128 function ending with CC=0\000"
/* offset=38723 */ "kmc_tdea_192\000pai_crypto\000pai_crypto\000KMC TDEA 192. Unit: pai_crypto \000event=0x1013\000\000\000\000\000\000KMC-TDEA-192 function ending with CC=0\000"
/* offset=38847 */ "kmctr_aes_128\000pai_crypto\000pai_crypto\000KMCTR AES 128. Unit: pai_crypto \000event=0x1036\000\000\000\000\000\000KMCTR-AES-128 function ending with CC=0\000"
/* offset=38974 */ "kmctr_aes_192\000pai_crypto\000pai_crypto\000KMCTR AES 192. Unit: pai_crypto \000event=0x1037\000\000\000\000\000\000KMCTR-AES-192 function ending with CC=0\000"
/* offset=39101 */ "kmctr_aes_256\000pai_crypto\000pai_crypto\000KMCTR AES 256. Unit: pai_crypto \000event=0x1038\000\000\000\000\000\000KMCTR-AES-256 function ending with CC=0\000"
/* offset=39228 */ "kmctr_dea\000pai_crypto\000pai_crypto\000KMCTR DEA. Unit: pai_crypto \000event=0x1030\000\000\000\000\000\000KMCTR-DEA function ending with CC=0\000"
/* offset=39343 */ "kmctr_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1039\000\000\000\000\000\000KMCTR-Encrypted-AES-128 function ending with CC=0\000"
/* offset=39500 */ "kmctr_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED AES 192. Unit: pai_crypto \000event=0x103a\000\000\000\000\000\000KMCTR-Encrypted-AES-192 function ending with CC=0\000"
/* offset=39657 */ "kmctr_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED AES 256. Unit: pai_crypto \000event=0x103b\000\000\000\000\000\000KMCTR-Encrypted-AES-256 function ending with CC=0\000"
/* offset=39814 */ "kmctr_encrypted_dea\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED DEA. Unit: pai_crypto \000event=0x1033\000\000\000\000\000\000KMCTR-Encrypted-DEA function ending with CC=0\000"
/* offset=39959 */ "kmctr_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1034\000\000\000\000\000\000KMCTR-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=40119 */ "kmctr_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1035\000\000\000\000\000\000KMCTR-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=40279 */ "kmctr_tdea_128\000pai_crypto\000pai_crypto\000KMCTR TDEA 128. Unit: pai_crypto \000event=0x1031\000\000\000\000\000\000KMCTR-TDEA-128 function ending with CC=0\000"
/* offset=40409 */ "kmctr_tdea_192\000pai_crypto\000pai_crypto\000KMCTR TDEA 192. Unit: pai_crypto \000event=0x1032\000\000\000\000\000\000KMCTR-TDEA-192 function ending with CC=0\000"
/* offset=40539 */ "kmf_aes_128\000pai_crypto\000pai_crypto\000KMF AES 128. Unit: pai_crypto \000event=0x102a\000\000\000\000\000\000KMF-AES-128 function ending with CC=0\000"
/* offset=40660 */ "kmf_aes_192\000pai_crypto\000pai_crypto\000KMF AES 192. Unit: pai_crypto \000event=0x102b\000\000\000\000\000\000KMF-AES-192 function ending with CC=0\000"
/* offset=40781 */ "kmf_aes_256\000pai_crypto\000pai_crypto\000KMF AES 256. Unit: pai_crypto \000event=0x102c\000\000\000\000\000\000KMF-AES-256 function ending with CC=0\000"
/* offset=40902 */ "kmf_dea\000pai_crypto\000pai_crypto\000KMF DEA. Unit: pai_crypto \000event=0x1024\000\000\000\000\000\000KMF-DEA function ending with CC=0\000"
/* offset=41011 */ "kmf_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMF ENCRYPTED AES 128. Unit: pai_crypto \000event=0x102d\000\000\000\000\000\000KMF-Encrypted-AES-128 function ending with CC=0\000"
/* offset=41162 */ "kmf_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMF ENCRYPTED AES 192. Unit: pai_crypto \000event=0x102e\000\000\000\000\000\000KMF-Encrypted-AES-192 function ending with CC=0\000"
/* offset=41313 */ "kmf_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMF ENCRYPTED AES 256. Unit: pai_crypto \000event=0x102f\000\000\000\000\000\000KMF-Encrypted-AES-256 function ending with CC=0\000"
/* offset=41464 */ "kmf_encrypted_dea\000pai_crypto\000pai_crypto\000KMF ENCRYPTED DEA. Unit: pai_crypto \000event=0x1027\000\000\000\000\000\000KMF-Encrypted-DEA function ending with CC=0\000"
/* offset=41603 */ "kmf_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMF ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1028\000\000\000\000\000\000KMF-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=41757 */ "kmf_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMF ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1029\000\000\000\000\000\000KMF-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=41911 */ "kmf_tdea_128\000pai_crypto\000pai_crypto\000KMF TDEA 128. Unit: pai_crypto \000event=0x1025\000\000\000\000\000\000KMF-TDEA-128 function ending with CC=0\000"
/* offset=42035 */ "kmf_tdea_192\000pai_crypto\000pai_crypto\000KMF TDEA 192. Unit: pai_crypto \000event=0x1026\000\000\000\000\000\000KMF-TDEA-192 function ending with CC=0\000"
/* offset=42159 */ "kmo_aes_128\000pai_crypto\000pai_crypto\000KMO AES 128. Unit: pai_crypto \000event=0x1042\000\000\000\000\000\000KMO-AES-128 function ending with CC=0\000"
/* offset=42280 */ "kmo_aes_192\000pai_crypto\000pai_crypto\000KMO AES 192. Unit: pai_crypto \000event=0x1043\000\000\000\000\000\000KMO-AES-192 function ending with CC=0\000"
/* offset=42401 */ "kmo_aes_256\000pai_crypto\000pai_crypto\000KMO AES 256. Unit: pai_crypto \000event=0x1044\000\000\000\000\000\000KMO-AES-256 function ending with CC=0\000"
/* offset=42522 */ "kmo_dea\000pai_crypto\000pai_crypto\000KMO DEA. Unit: pai_crypto \000event=0x103c\000\000\000\000\000\000KMO-DEA function ending with CC=0\000"
/* offset=42631 */ "kmo_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMO ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1045\000\000\000\000\000\000KMO-Encrypted-AES-128 function ending with CC=0\000"
/* offset=42782 */ "kmo_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMO ENCRYPTED AES 192. Unit: pai_crypto \000event=0x1046\000\000\000\000\000\000KMO-Encrypted-AES-192 function ending with CC=0\000"
/* offset=42933 */ "kmo_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMO ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1047\000\000\000\000\000\000KMO-Encrypted-AES-256 function ending with CC=0\000"
/* offset=43084 */ "kmo_encrypted_dea\000pai_crypto\000pai_crypto\000KMO ENCRYPTED DEA. Unit: pai_crypto \000event=0x103f\000\000\000\000\000\000KMO-Encrypted-DEA function ending with CC=0\000"
/* offset=43223 */ "kmo_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMO ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1040\000\000\000\000\000\000KMO-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=43377 */ "kmo_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMO ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1041\000\000\000\000\000\000KMO-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=43531 */ "kmo_tdea_128\000pai_crypto\000pai_crypto\000KMO TDEA 128. Unit: pai_crypto \000event=0x103d\000\000\000\000\000\000KMO-TDEA-128 function ending with CC=0\000"
/* offset=43655 */ "kmo_tdea_192\000pai_crypto\000pai_crypto\000KMO TDEA 192. Unit: pai_crypto \000event=0x103e\000\000\000\000\000\000KMO-TDEA-192 function ending with CC=0\000"
/* offset=43779 */ "l1c_tlb1_misses\000cpum_cf\000extended\000L1C TLB1 Misses. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000Increments by one for any cycle where a Level-1 cache or Level-1 TLB miss is in progress\000"
/* offset=43949 */ "l1c_tlb2_misses\000cpum_cf\000extended\000L1C TLB2 Misses. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress\000"
/* offset=44119 */ "l1d_dir_writes\000cpum_cf\000basic\000Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x4\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes\000"
/* offset=44293 */ "l1d_l2_sourced_writes\000cpum_cf\000extended\000L1D L2 Sourced Writes. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from the Level-2 cache\000"
/* offset=44505 */ "l1d_l2_sourced_writes\000cpum_cf\000extended\000L1D L2 Sourced Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from the Level-2 (L1.5) cache\000"
/* offset=44725 */ "l1d_l2d_sourced_writes\000cpum_cf\000extended\000L1D L2D Sourced Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000"
/* offset=44944 */ "l1d_l2d_sourced_writes\000cpum_cf\000extended\000L1D L2D Sourced Writes. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000"
/* offset=45163 */ "l1d_l2i_sourced_writes\000cpum_cf\000extended\000L1D L2I Sourced Writes. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000"
/* offset=45389 */ "l1d_l3_local_writes\000cpum_cf\000extended\000L1D L3 Local Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the installed cache line was source from the Level-3 cache that is on the same book as the Data cache (Local L2 cache)\000"
/* offset=45657 */ "l1d_l3_remote_writes\000cpum_cf\000extended\000L1D L3 Remote Writes. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Data cache (Remote L2 cache)\000"
/* offset=45931 */ "l1d_lmem_sourced_writes\000cpum_cf\000extended\000L1D Local Memory Sourced Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000"
/* offset=46212 */ "l1d_lmem_sourced_writes\000cpum_cf\000extended\000L1D Local Memory Sourced Writes. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A directory write to the Level-1 Data cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000"
/* offset=46483 */ "l1d_lmem_sourced_writes\000cpum_cf\000extended\000L1D Local Memory Sourced Writes. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A directory write to the Level-1 Data Cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000"
/* offset=46754 */ "l1d_offbook_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Book L3 Sourced Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-3 cache\000"
/* offset=46991 */ "l1d_offbook_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Book L3 Sourced Writes. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention\000"
/* offset=47249 */ "l1d_offbook_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Book L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention\000"
/* offset=47525 */ "l1d_offbook_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000"
/* offset=47762 */ "l1d_offbook_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000"
/* offset=47999 */ "l1d_offchip_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention\000"
/* offset=48265 */ "l1d_offchip_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache\000"
/* offset=48510 */ "l1d_offchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x97\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention\000"
/* offset=48794 */ "l1d_offcluster_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000"
/* offset=49061 */ "l1d_offcluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000"
/* offset=49346 */ "l1d_offcluster_memory_sourced_writes\000cpum_cf\000extended\000L1D Off-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0x97\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Cluster memory\000"
/* offset=49590 */ "l1d_offdrawer_fcol_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes. Unit: cpum_cf \000event=0x9d\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention\000"
/* offset=49881 */ "l1d_offdrawer_fcol_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x9c\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention\000"
/* offset=50190 */ "l1d_offdrawer_fcol_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache\000"
/* offset=50460 */ "l1d_offdrawer_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000"
/* offset=50724 */ "l1d_offdrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000"
/* offset=51006 */ "l1d_offdrawer_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0x9d\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000"
/* offset=51246 */ "l1d_offdrawer_mem_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0xa0\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=51484 */ "l1d_offdrawer_memory_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0x9a\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=51725 */ "l1d_offdrawer_scol_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Same-Column L3 Sourced Writes. Unit: cpum_cf \000event=0x9a\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention\000"
/* offset=52018 */ "l1d_offdrawer_scol_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Drawer Same-Column L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention\000"
/* offset=52329 */ "l1d_offdrawer_scol_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Same-Column L4 Sourced Writes. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache\000"
/* offset=52601 */ "l1d_onbook_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Book Level-4 cache\000"
/* offset=52835 */ "l1d_onbook_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Book Level-4 cache\000"
/* offset=53069 */ "l1d_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x90\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention\000"
/* offset=53324 */ "l1d_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x90\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000"
/* offset=53579 */ "l1d_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Chip Level-3 cache\000"
/* offset=53813 */ "l1d_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000"
/* offset=54086 */ "l1d_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000"
/* offset=54359 */ "l1d_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from a On Chip Level-3 cache with intervention\000"
/* offset=54631 */ "l1d_onchip_l3_sourced_writes_ro\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes read-only. Unit: cpum_cf \000event=0x9e\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip L3 but a read-only invalidate was done to remove other copies of the cache line\000"
/* offset=54941 */ "l1d_onchip_mem_sourced_writes\000cpum_cf\000extended\000L1D On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0xa1\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=55170 */ "l1d_onchip_memory_sourced_writes\000cpum_cf\000extended\000L1D On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=55402 */ "l1d_oncluster_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Cluster Level-3 cache without intervention\000"
/* offset=55663 */ "l1d_oncluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x95\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache with intervention\000"
/* offset=55945 */ "l1d_oncluster_memory_sourced_writes\000cpum_cf\000extended\000L1D On-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster memory\000"
/* offset=56189 */ "l1d_ondrawer_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0x97\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention\000"
/* offset=56450 */ "l1d_ondrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention\000"
/* offset=56729 */ "l1d_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0x95\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache\000"
/* offset=56969 */ "l1d_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0x9c\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000"
/* offset=57206 */ "l1d_ondrawer_mem_sourced_writes\000cpum_cf\000extended\000L1D On-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0x9f\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=57441 */ "l1d_onnode_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Node L3 Sourced Writes. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention\000"
/* offset=57696 */ "l1d_onnode_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Node L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention\000"
/* offset=57969 */ "l1d_onnode_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Node L4 Sourced Writes. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-4 cache\000"
/* offset=58203 */ "l1d_onnode_mem_sourced_writes\000cpum_cf\000extended\000L1D On-Node Memory Sourced Writes. Unit: cpum_cf \000event=0x9e\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Node memory\000"
/* offset=58432 */ "l1d_penalty_cycles\000cpum_cf\000basic\000Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x5\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000"
/* offset=58616 */ "l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000"
/* offset=58910 */ "l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x88\000\000\000\000\000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000"
/* offset=59204 */ "l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000"
/* offset=59498 */ "l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000"
/* offset=59792 */ "l1i_cacheline_invalidates\000cpum_cf\000extended\000L1I Cacheline Invalidates. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A cache line in the Level-1 Instruction Cache has been invalidated by a store on the same CPU as the Level-1 Instruction Cache\000"
/* offset=60020 */ "l1i_dir_writes\000cpum_cf\000basic\000Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x2\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000"
/* offset=60218 */ "l1i_l2_sourced_writes\000cpum_cf\000extended\000L1I L2 Sourced Writes. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 (L1.5) cache\000"
/* offset=60444 */ "l1i_l2_sourced_writes\000cpum_cf\000extended\000L1I L2 Sourced Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 cache\000"
/* offset=60663 */ "l1i_l2i_sourced_writes\000cpum_cf\000extended\000L1I L2I Sourced Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000"
/* offset=60896 */ "l1i_l2i_sourced_writes\000cpum_cf\000extended\000L1I L2I Sourced Writes. Unit: cpum_cf \000event=0x88\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000"
/* offset=61129 */ "l1i_l3_local_writes\000cpum_cf\000extended\000L1I L3 Local Writes. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from the Level-3 cache that is on the same book as the Instruction cache (Local L2 cache)\000"
/* offset=61412 */ "l1i_l3_remote_writes\000cpum_cf\000extended\000L1I L3 Remote Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Instruction cache (Remote L2 cache)\000"
/* offset=61700 */ "l1i_lmem_sourced_writes\000cpum_cf\000extended\000L1I Local Memory Sourced Writes. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the s ame book as the Instruction cache (Local Memory)\000"
/* offset=61986 */ "l1i_lmem_sourced_writes\000cpum_cf\000extended\000L1I Local Memory Sourced Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A directory write to the Level-1 Instruction cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)\000"
/* offset=62271 */ "l1i_lmem_sourced_writes\000cpum_cf\000extended\000L1I Local Memory Sourced Writes. Unit: cpum_cf \000event=0x8e\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)\000"
/* offset=62556 */ "l1i_offbook_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Book L3 Sourced Writes. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-3 cache\000"
/* offset=62800 */ "l1i_offbook_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Book L3 Sourced Writes. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention\000"
/* offset=63065 */ "l1i_offbook_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Book L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa1\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention\000"
/* offset=63348 */ "l1i_offbook_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000"
/* offset=63592 */ "l1i_offbook_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x9d\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000"
/* offset=63836 */ "l1i_offchip_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x9a\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention\000"
/* offset=64109 */ "l1i_offchip_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache\000"
/* offset=64361 */ "l1i_offchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa0\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention\000"
/* offset=64652 */ "l1i_offcluster_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0xa8\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000"
/* offset=64926 */ "l1i_offcluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xaa\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000"
/* offset=65218 */ "l1i_offcluster_memory_sourced_writes\000cpum_cf\000extended\000L1I Off-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0xa9\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Cluster memory\000"
/* offset=65469 */ "l1i_offdrawer_fcol_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Far-Column L3 Sourced Writes. Unit: cpum_cf \000event=0xaf\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention\000"
/* offset=65767 */ "l1i_offdrawer_fcol_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Drawer Far-Column L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xae\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention\000"
/* offset=66083 */ "l1i_offdrawer_fcol_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Far-Column L4 Sourced Writes. Unit: cpum_cf \000event=0xad\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache\000"
/* offset=66360 */ "l1i_offdrawer_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0xab\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000"
/* offset=66631 */ "l1i_offdrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xad\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000"
/* offset=66920 */ "l1i_offdrawer_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0xaf\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000"
/* offset=67167 */ "l1i_offdrawer_mem_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0xb2\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=67411 */ "l1i_offdrawer_memory_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0xac\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=67659 */ "l1i_offdrawer_scol_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Same-Column L3 Sourced Writes. Unit: cpum_cf \000event=0xac\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention\000"
/* offset=67959 */ "l1i_offdrawer_scol_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Drawer Same-Column L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xab\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention\000"
/* offset=68277 */ "l1i_offdrawer_scol_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Same-Column L4 Sourced Writes. Unit: cpum_cf \000event=0xaa\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache\000"
/* offset=68556 */ "l1i_onbook_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x88\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Book Level-4 cache\000"
/* offset=68797 */ "l1i_onbook_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x9c\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Book Level-4 cache\000"
/* offset=69038 */ "l1i_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Chip Level-3 cache\000"
/* offset=69279 */ "l1i_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention\000"
/* offset=69541 */ "l1i_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0xa2\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache without intervention\000"
/* offset=69802 */ "l1i_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0xa2\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000"
/* offset=70064 */ "l1i_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x9f\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention\000"
/* offset=70344 */ "l1i_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa3\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention\000"
/* offset=70624 */ "l1i_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa4\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache with intervention\000"
/* offset=70903 */ "l1i_onchip_mem_sourced_writes\000cpum_cf\000extended\000L1I On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0xb3\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=71139 */ "l1i_onchip_memory_sourced_writes\000cpum_cf\000extended\000L1I On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0xa3\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from On-Chip memory\000"
/* offset=71377 */ "l1i_oncluster_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0xa5\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache without intervention\000"
/* offset=71648 */ "l1i_oncluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa7\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Cluster Level-3 cache with intervention\000"
/* offset=71934 */ "l1i_oncluster_memory_sourced_writes\000cpum_cf\000extended\000L1I On-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0xa6\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster memory\000"
/* offset=72185 */ "l1i_ondrawer_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0xa9\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention\000"
/* offset=72453 */ "l1i_ondrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa8\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention\000"
/* offset=72739 */ "l1i_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0xa7\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache\000"
/* offset=72986 */ "l1i_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0xae\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000"
/* offset=73230 */ "l1i_ondrawer_mem_sourced_writes\000cpum_cf\000extended\000L1I On-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0xb1\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=73472 */ "l1i_onnode_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Node L3 Sourced Writes. Unit: cpum_cf \000event=0xa6\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention\000"
/* offset=73734 */ "l1i_onnode_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Node L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa5\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention\000"
/* offset=74014 */ "l1i_onnode_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L4 Sourced Writes. Unit: cpum_cf \000event=0xa4\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-4 cache\000"
/* offset=74255 */ "l1i_onnode_mem_sourced_writes\000cpum_cf\000extended\000L1I On-Node Memory Sourced Writes. Unit: cpum_cf \000event=0xb0\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Node memory\000"
/* offset=74491 */ "l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x3\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000"
/* offset=74699 */ "l2c_stores_sent\000cpum_cf\000extended\000L2C Stores Sent. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000Incremented by one for every store sent to Level-2 cache\000"
/* offset=74837 */ "l2c_stores_sent\000cpum_cf\000extended\000L2C Stores Sent. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000Incremented by one for every store sent to Level-2 (L1.5) cache\000"
/* offset=74982 */ "l3_cache_rd\000\000cache\000L3 cache access, read\000event=0x40\000\000\000\000\000\000Attributable Level 3 cache access, read\000"
/* offset=75079 */ "last_host_translations\000cpum_cf\000extended\000Last host translation done. Unit: cpum_cf \000event=0xe8\000\000\000\000\000\000Last Host Translation done\000"
/* offset=75205 */ "mt_diag_cycles_one_thr_active\000cpum_cf\000extended\000Cycle count with one thread active. Unit: cpum_cf \000event=0x1c0\000\000\000\000\000\000Cycle count with one thread active\000"
/* offset=75355 */ "mt_diag_cycles_two_thr_active\000cpum_cf\000extended\000Cycle count with two threads active. Unit: cpum_cf \000event=0x1c1\000\000\000\000\000\000Cycle count with two threads active\000"
/* offset=75507 */ "nnpa_completions\000cpum_cf\000extended\000NNPA Total completions. Unit: cpum_cf \000event=0x10c\000\000\000\000\000\000Increments by one for every Neural Network Processing Assist instruction executed that ended in Condition Codes 0, 1 or 2\000"
/* offset=75719 */ "nnpa_hold_lock\000cpum_cf\000extended\000Cycles spent holding NNPA lock. Unit: cpum_cf \000event=0x10e\000\000\000\000\000\000Cycles CPU is using IBM Z Integrated Accelerator for AI\000"
/* offset=75871 */ "nnpa_invocations\000cpum_cf\000extended\000NNPA Total invocations. Unit: cpum_cf \000event=0x10b\000\000\000\000\000\000Increments by one for every Neural Network Processing Assist instruction executed\000"
/* offset=76043 */ "nnpa_wait_lock\000cpum_cf\000extended\000Cycles spent obtaining NNPA lock. Unit: cpum_cf \000event=0x10d\000\000\000\000\000\000Cycles CPU spent obtaining access to IBM Z Integrated Accelerator for AI\000"
/* offset=76214 */ "pcc_compute_last_block_cmac_using_aes_128\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 128. Unit: pai_crypto \000event=0x106d\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-AES-128 function ending with CC=0\000"
/* offset=76425 */ "pcc_compute_last_block_cmac_using_aes_192\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 192. Unit: pai_crypto \000event=0x106e\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-AES-192 function ending with CC=0\000"
/* offset=76636 */ "pcc_compute_last_block_cmac_using_aes_256\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 256. Unit: pai_crypto \000event=0x106f\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-AES-256 function ending with CC=0\000"
/* offset=76847 */ "pcc_compute_last_block_cmac_using_dea\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING DEA. Unit: pai_crypto \000event=0x1067\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-DEA function ending with CC=0\000"
/* offset=77046 */ "pcc_compute_last_block_cmac_using_encrypted_aes_128\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1070\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 128 function ending with CC=0\000"
/* offset=77288 */ "pcc_compute_last_block_cmac_using_encrypted_aes_192\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 192. Unit: pai_crypto \000event=0x1071\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 192 function ending with CC=0\000"
/* offset=77530 */ "pcc_compute_last_block_cmac_using_encrypted_aes_256a\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 256A. Unit: pai_crypto \000event=0x1072\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 256A function ending with CC=0\000"
/* offset=77775 */ "pcc_compute_last_block_cmac_using_encrypted_dea\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED DEA. Unit: pai_crypto \000event=0x106a\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-DEA function ending with CC=0\000"
/* offset=78004 */ "pcc_compute_last_block_cmac_using_encrypted_tdea_128\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x106b\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-TDEA- 128 function ending with CC=0\000"
/* offset=78249 */ "pcc_compute_last_block_cmac_using_encrypted_tdea_192\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x106c\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-TDEA- 192 function ending with CC=0\000"
/* offset=78494 */ "pcc_compute_last_block_cmac_using_tdea_128\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING TDEA 128. Unit: pai_crypto \000event=0x1068\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-TDEA-128 function ending with CC=0\000"
/* offset=78708 */ "pcc_compute_last_block_cmac_using_tdea_192\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING TDEA 192. Unit: pai_crypto \000event=0x1069\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-TDEA-192 function ending with CC=0\000"
/* offset=78922 */ "pcc_compute_xts_parameter_using_aes_128\000pai_crypto\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING AES 128. Unit: pai_crypto \000event=0x1073\000\000\000\000\000\000PCC-Compute-XTS-Parameter-Using-AES-128 function ending with CC=0\000"
/* offset=79127 */ "pcc_compute_xts_parameter_using_aes_256\000pai_crypto\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING AES 256. Unit: pai_crypto \000event=0x1074\000\000\000\000\000\000PCC-Compute-XTS-Parameter-Using-AES-256 function ending with CC=0\000"
/* offset=79332 */ "pcc_compute_xts_parameter_using_encrypted_aes_128\000pai_crypto\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1075\000\000\000\000\000\000PCC-Compute-XTS-Parameter-Using-Encrypted-AES-128 function ending with CC=0\000"
/* offset=79567 */ "pcc_compute_xts_parameter_using_encrypted_aes_256\000pai_crypto\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1076\000\000\000\000\000\000PCC-Compute-XTS-Parameter-Using-Encrypted-AES-256 function ending with CC=0\000"
/* offset=79802 */ "pcc_scalar_multiply_ed25519\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY ED25519. Unit: pai_crypto \000event=0x107a\000\000\000\000\000\000PCC-Scalar-Multiply-Ed25519 function ending with CC=0\000"
/* offset=79971 */ "pcc_scalar_multiply_ed448\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY ED448. Unit: pai_crypto \000event=0x107b\000\000\000\000\000\000PCC-Scalar-Multiply-Ed448 function ending with CC=0\000"
/* offset=80134 */ "pcc_scalar_multiply_p256\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY P256. Unit: pai_crypto \000event=0x1077\000\000\000\000\000\000PCC-Scalar-Multiply-P256 function ending with CC=0\000"
/* offset=80294 */ "pcc_scalar_multiply_p384\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY P384. Unit: pai_crypto \000event=0x1078\000\000\000\000\000\000PCC-Scalar-Multiply-P384 function ending with CC=0\000"
/* offset=80454 */ "pcc_scalar_multiply_p521\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY P521. Unit: pai_crypto \000event=0x1079\000\000\000\000\000\000PCC-Scalar-Multiply-P521 function ending with CC=0\000"
/* offset=80614 */ "pcc_scalar_multiply_x25519\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY X25519. Unit: pai_crypto \000event=0x107c\000\000\000\000\000\000PCC-Scalar-Multiply-X25519 function ending with CC=0\000"
/* offset=80780 */ "pcc_scalar_multiply_x448\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY X448. Unit: pai_crypto \000event=0x107d\000\000\000\000\000\000PCC-Scalar-Multiply-X448 function ending with CC=0\000"
/* offset=80940 */ "pckmo_encrypt_aes_128_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT AES 128 KEY. Unit: pai_crypto \000event=0x1093\000\000\000\000\000\000PCKMO-Encrypt-AES-128-key function\000"
/* offset=81086 */ "pckmo_encrypt_aes_192_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT AES 192 KEY. Unit: pai_crypto \000event=0x1094\000\000\000\000\000\000PCKMO-Encrypt-AES-192-key function\000"
/* offset=81232 */ "pckmo_encrypt_aes_256_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT AES 256 KEY. Unit: pai_crypto \000event=0x1095\000\000\000\000\000\000PCKMO-Encrypt-AES-256-key function\000"
/* offset=81378 */ "pckmo_encrypt_dea_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT DEA KEY. Unit: pai_crypto \000event=0x1090\000\000\000\000\000\000PCKMO-Encrypt-DEA-key function\000"
/* offset=81512 */ "pckmo_encrypt_ecc_ed25519_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC ED25519 KEY. Unit: pai_crypto \000event=0x1099\000\000\000\000\000\000PCKMO-Encrypt-ECC-Ed25519-key function\000"
/* offset=81670 */ "pckmo_encrypt_ecc_ed448_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC ED448 KEY. Unit: pai_crypto \000event=0x109a\000\000\000\000\000\000PCKMO-Encrypt-ECC-Ed448-key function\000"
/* offset=81822 */ "pckmo_encrypt_ecc_p256_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC P256 KEY. Unit: pai_crypto \000event=0x1096\000\000\000\000\000\000PCKMO-Encrypt-ECC-P256-key function\000"
/* offset=81971 */ "pckmo_encrypt_ecc_p384_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC P384 KEY. Unit: pai_crypto \000event=0x1097\000\000\000\000\000\000PCKMO-Encrypt-ECC-P384-key function\000"
/* offset=82120 */ "pckmo_encrypt_ecc_p521_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC P521 KEY. Unit: pai_crypto \000event=0x1098\000\000\000\000\000\000PCKMO-Encrypt-ECC-P521-key function\000"
/* offset=82269 */ "pckmo_encrypt_tdea_128_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT TDEA 128 KEY. Unit: pai_crypto \000event=0x1091\000\000\000\000\000\000PCKMO-Encrypt-TDEA-128-key function\000"
/* offset=82418 */ "pckmo_encrypt_tdea_192_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT TDEA 192 KEY. Unit: pai_crypto \000event=0x1092\000\000\000\000\000\000PCKMO-Encrypt-TDEA-192-key function\000"
/* offset=82567 */ "prng_blocked_cycles\000cpum_cf\000crypto6\000PRNG Blocked Cycle Count. Unit: cpum_cf \000event=0x43\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=82874 */ "prng_blocked_cycles\000cpum_cf\000crypto\000PRNG Blocked Cycle Count. Unit: cpum_cf \000event=0x43\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=83180 */ "prng_blocked_functions\000cpum_cf\000crypto6\000PRNG Blocked Function Count. Unit: cpum_cf \000event=0x42\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=83495 */ "prng_blocked_functions\000cpum_cf\000crypto\000PRNG Blocked Function Count. Unit: cpum_cf \000event=0x42\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=83809 */ "prng_cycles\000cpum_cf\000crypto6\000PRNG Cycle Count. Unit: cpum_cf \000event=0x41\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000"
/* offset=84053 */ "prng_cycles\000cpum_cf\000crypto\000PRNG Cycle Count. Unit: cpum_cf \000event=0x41\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000"
/* offset=84296 */ "prng_functions\000cpum_cf\000crypto6\000PRNG Function Count. Unit: cpum_cf \000event=0x40\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000"
/* offset=84482 */ "prng_functions\000cpum_cf\000crypto\000PRNG Function Count. Unit: cpum_cf \000event=0x40\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000"
/* offset=84667 */ "prno_sha_512_drng\000pai_crypto\000pai_crypto\000PRNO SHA 512 DRNG. Unit: pai_crypto \000event=0x107e\000\000\000\000\000\000PRNO-SHA-512-DRNG function ending with CC=0\000"
/* offset=84806 */ "prno_trng\000pai_crypto\000pai_crypto\000PRNO TRNG. Unit: pai_crypto \000event=0x1080\000\000\000\000\000\000PRNO-TRNG function ending with CC=0\000"
/* offset=84921 */ "prno_trng_query_raw_to_conditioned_ratio\000pai_crypto\000pai_crypto\000PRNO TRNG QUERY RAW TO CONDITIONED RATIO. Unit: pai_crypto \000event=0x107f\000\000\000\000\000\000PRNO-TRNG-Query-Raw-to-Conditioned-Ratio function ending with CC=0\000"
/* offset=85129 */ "problem_state_cpu_cycles\000cpum_cf\000basic\000Problem-State Cycle Count. Unit: cpum_cf \000event=0x20\000\000\000\000\000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000"
/* offset=85381 */ "problem_state_instructions\000cpum_cf\000basic\000Problem-State Instruction Count. Unit: cpum_cf \000event=0x21\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000"
/* offset=85586 */ "problem_state_l1d_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x24\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000"
/* offset=85827 */ "problem_state_l1d_penalty_cycles\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x25\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000"
/* offset=86072 */ "problem_state_l1i_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x22\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000"
/* offset=86337 */ "problem_state_l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x23\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000"
/* offset=86592 */ "segment_reg_loads.any\000\000other\000Number of segment register loads\000event=0x6,period=200000,umask=0x80\000\000\000\000\000\000\000"
/* offset=86695 */ "sha_blocked_cycles\000cpum_cf\000crypto6\000SHA Blocked Cycle Count. Unit: cpum_cf \000event=0x47\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=86965 */ "sha_blocked_cycles\000cpum_cf\000crypto\000SHA Blocked Cycle Count. Unit: cpum_cf \000event=0x47\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=87234 */ "sha_blocked_functions\000cpum_cf\000crypto6\000SHA Blocked Function Count. Unit: cpum_cf \000event=0x46\000\000\000\000\000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=87512 */ "sha_blocked_functions\000cpum_cf\000crypto\000SHA Blocked Function Count. Unit: cpum_cf \000event=0x46\000\000\000\000\000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=87789 */ "sha_cycles\000cpum_cf\000crypto6\000SHA Cycle Count. Unit: cpum_cf \000event=0x45\000\000\000\000\000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000"
/* offset=87995 */ "sha_cycles\000cpum_cf\000crypto\000SHA Cycle Count. Unit: cpum_cf \000event=0x45\000\000\000\000\000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000"
/* offset=88200 */ "sha_functions\000cpum_cf\000crypto6\000SHA Function Count. Unit: cpum_cf \000event=0x44\000\000\000\000\000\000This counter counts the total number of the SHA functions issued by the CPU\000"
/* offset=88357 */ "sha_functions\000cpum_cf\000crypto\000SHA Function Count. Unit: cpum_cf \000event=0x44\000\000\000\000\000\000This counter counts the total number of the SHA functions issued by the CPU\000"
/* offset=88513 */ "sortl\000cpum_cf\000extended\000Count SORTL instructions. Unit: cpum_cf \000event=0x100\000\000\000\000\000\000Increments by one for every SORT LISTS instruction executed\000"
/* offset=88654 */ "sys_ccn_pmu.read_cycles\000uncore_sys_ccn_pmu\000uncore\000ccn read-cycles event. Unit: uncore_sys_ccn_pmu \000config=0x2c\000\0000x01\000\000\000\000\000"
/* offset=88775 */ "sys_ddr_pmu.write_cycles\000uncore_sys_ddr_pmu\000uncore\000ddr write-cycles event. Unit: uncore_sys_ddr_pmu \000event=0x2b\000\000v8\000\000\000\000\000"
/* offset=88895 */ "tlb2_crste_hpage_writes\000cpum_cf\000extended\000TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays for a one-megabyte large page translation\000"
/* offset=89145 */ "tlb2_crste_hpage_writes\000cpum_cf\000extended\000TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf \000event=0x8e\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000"
/* offset=89393 */ "tlb2_crste_hpage_writes\000cpum_cf\000extended\000TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000"
/* offset=89641 */ "tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000"
/* offset=89864 */ "tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays\000"
/* offset=90048 */ "tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000"
/* offset=90230 */ "tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000"
/* offset=90412 */ "tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000"
/* offset=90594 */ "tlb2_crste_writes\000cpum_cf\000extended\000TLB2 Combined Region and Segment Entry Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000"
/* offset=90845 */ "tlb2_engines_busy\000cpum_cf\000extended\000TLB2 Engines Busy. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000The number of Level-2 TLB translation engines busy in a cycle\000"
/* offset=90992 */ "tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000"
/* offset=91153 */ "tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000"
/* offset=91317 */ "tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000"
/* offset=91478 */ "tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000"
/* offset=91639 */ "tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000"
/* offset=91800 */ "tlb2_pte_writes\000cpum_cf\000extended\000TLB2 Page Table Entry Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000"
/* offset=91977 */ "transaction\000\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000Transaction count\000\000\000\000\000"
/* offset=92098 */ "tx_c_tabort_no_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf \000event=0xb2\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000"
/* offset=92408 */ "tx_c_tabort_no_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf \000event=0xdb\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000"
/* offset=92718 */ "tx_c_tabort_no_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf \000event=0xf4\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000"
/* offset=93028 */ "tx_c_tabort_no_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode. Unit: cpum_cf \000event=0xf5\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000"
/* offset=93303 */ "tx_c_tabort_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf \000event=0xb3\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000"
/* offset=93598 */ "tx_c_tabort_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf \000event=0xdc\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000"
/* offset=93893 */ "tx_c_tabort_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf \000event=0xf5\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000"
/* offset=94188 */ "tx_c_tabort_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf \000event=0xf6\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000"
/* offset=94483 */ "tx_c_tend\000cpum_cf\000extended\000Completed TEND instructions in constrained TX mode. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A TEND instruction has completed in a constrained transactional-execution mode\000"
/* offset=94672 */ "tx_c_tend\000cpum_cf\000extended\000Completed TEND instructions in constrained TX mode. Unit: cpum_cf \000event=0x9e\000\000\000\000\000\000A TEND instruction has completed in a constrained transactional-execution mode\000"
/* offset=94861 */ "tx_nc_tabort\000cpum_cf\000extended\000Aborted transactions in non-constrained TX mode. Unit: cpum_cf \000event=0xb1\000\000\000\000\000\000A transaction abort has occurred in a nonconstrained transactional-execution mode\000"
/* offset=95053 */ "tx_nc_tabort\000cpum_cf\000extended\000Aborted transactions in non-constrained TX mode. Unit: cpum_cf \000event=0xda\000\000\000\000\000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000"
/* offset=95246 */ "tx_nc_tabort\000cpum_cf\000extended\000Aborted transactions in non-constrained TX mode. Unit: cpum_cf \000event=0xf3\000\000\000\000\000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000"
/* offset=95439 */ "tx_nc_tabort\000cpum_cf\000extended\000Aborted transactions in unconstrained TX mode. Unit: cpum_cf \000event=0xf4\000\000\000\000\000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000"
/* offset=95630 */ "tx_nc_tend\000cpum_cf\000extended\000Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000"
/* offset=95828 */ "tx_nc_tend\000cpum_cf\000extended\000Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf \000event=0x95\000\000\000\000\000\000A TEND instruction has completed in a nonconstrained transactional-execution mode\000"
/* offset=96025 */ "unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\000\000\000\000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000"
/* offset=96289 */ "uncore_hisi_ddrc.flux_wcmd\000hisi_sccl,ddrc\000uncore\000DDRC write commands. Unit: hisi_sccl,ddrc \000event=0x2\000\000\000\000\000\000DDRC write commands\000"
/* offset=96416 */ "uncore_hisi_l3c.rd_hit_cpipe\000hisi_sccl,l3c\000uncore\000Total read hits. Unit: hisi_sccl,l3c \000event=0x7\000\000\000\000\000\000Total read hits\000"
/* offset=96535 */ "uncore_imc.cache_hits\000uncore_imc\000uncore\000Total cache hits. Unit: uncore_imc \000event=0x34\000\000\000\000\000\000Total cache hits\000"
/* offset=96644 */ "uncore_imc_free_running.cache_miss\000uncore_imc_free_running\000uncore\000Total cache misses. Unit: uncore_imc_free_running \000event=0x12\000\000\000\000\000\000Total cache misses\000"
/* offset=96796 */ "vx_bcd_execution_slots\000cpum_cf\000extended\000Count finished vector arithmetic Binary Coded Decimal instructions. Unit: cpum_cf \000event=0xe1\000\000\000\000\000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMP, VMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOP, VCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVD, VCVDG\000"
/* offset=97164 */ "vx_bcd_execution_slots\000cpum_cf\000extended\000VX BCD Execution Slots. Unit: cpum_cf \000event=0xe1\000\000\000\000\000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMPVMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOPVCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVDVCVDG\000"
;

static const struct compact_pmu_event pmu_events__cf_z196[] = {
{ 3351 }, /* cpu_cycles\000cpum_cf\000basic\000Cycle Count. Unit: cpum_cf \000event=0\000\000\000\000\000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 24736 }, /* instructions\000cpum_cf\000basic\000Instruction Count. Unit: cpum_cf \000event=0x1\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 44119 }, /* l1d_dir_writes\000cpum_cf\000basic\000Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x4\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 58432 }, /* l1d_penalty_cycles\000cpum_cf\000basic\000Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x5\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 60020 }, /* l1i_dir_writes\000cpum_cf\000basic\000Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x2\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 74491 }, /* l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x3\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 85129 }, /* problem_state_cpu_cycles\000cpum_cf\000basic\000Problem-State Cycle Count. Unit: cpum_cf \000event=0x20\000\000\000\000\000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 85381 }, /* problem_state_instructions\000cpum_cf\000basic\000Problem-State Instruction Count. Unit: cpum_cf \000event=0x21\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 85586 }, /* problem_state_l1d_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x24\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000 */
{ 85827 }, /* problem_state_l1d_penalty_cycles\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x25\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000 */
{ 86072 }, /* problem_state_l1i_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x22\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000 */
{ 86337 }, /* problem_state_l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x23\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000 */
{ 1054 }, /* aes_blocked_cycles\000cpum_cf\000crypto\000AES Blocked Cycle Count. Unit: cpum_cf \000event=0x4f\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 1609 }, /* aes_blocked_functions\000cpum_cf\000crypto\000AES Blocked Function Count. Unit: cpum_cf \000event=0x4e\000\000\000\000\000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 2100 }, /* aes_cycles\000cpum_cf\000crypto\000AES Cycle Count. Unit: cpum_cf \000event=0x4d\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 2466 }, /* aes_functions\000cpum_cf\000crypto\000AES Function Count. Unit: cpum_cf \000event=0x4c\000\000\000\000\000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 8273 }, /* dea_blocked_cycles\000cpum_cf\000crypto\000DEA Blocked Cycle Count. Unit: cpum_cf \000event=0x4b\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 8828 }, /* dea_blocked_functions\000cpum_cf\000crypto\000DEA Blocked Function Count. Unit: cpum_cf \000event=0x4a\000\000\000\000\000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 9319 }, /* dea_cycles\000cpum_cf\000crypto\000DEA Cycle Count. Unit: cpum_cf \000event=0x49\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 9685 }, /* dea_functions\000cpum_cf\000crypto\000DEA Function Count. Unit: cpum_cf \000event=0x48\000\000\000\000\000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 82874 }, /* prng_blocked_cycles\000cpum_cf\000crypto\000PRNG Blocked Cycle Count. Unit: cpum_cf \000event=0x43\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 83495 }, /* prng_blocked_functions\000cpum_cf\000crypto\000PRNG Blocked Function Count. Unit: cpum_cf \000event=0x42\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 84053 }, /* prng_cycles\000cpum_cf\000crypto\000PRNG Cycle Count. Unit: cpum_cf \000event=0x41\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 84482 }, /* prng_functions\000cpum_cf\000crypto\000PRNG Function Count. Unit: cpum_cf \000event=0x40\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 86965 }, /* sha_blocked_cycles\000cpum_cf\000crypto\000SHA Blocked Cycle Count. Unit: cpum_cf \000event=0x47\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87512 }, /* sha_blocked_functions\000cpum_cf\000crypto\000SHA Blocked Function Count. Unit: cpum_cf \000event=0x46\000\000\000\000\000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87995 }, /* sha_cycles\000cpum_cf\000crypto\000SHA Cycle Count. Unit: cpum_cf \000event=0x45\000\000\000\000\000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 88357 }, /* sha_functions\000cpum_cf\000crypto\000SHA Function Count. Unit: cpum_cf \000event=0x44\000\000\000\000\000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 12347 }, /* dtlb1_hpage_writes\000cpum_cf\000extended\000DTLB1 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000 */
{ 12729 }, /* dtlb1_misses\000cpum_cf\000extended\000DTLB1 Misses. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000 */
{ 13583 }, /* dtlb1_writes\000cpum_cf\000extended\000DTLB1 Writes. Unit: cpum_cf \000event=0x90\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000 */
{ 25065 }, /* itlb1_misses\000cpum_cf\000extended\000ITLB1 Misses. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress\000 */
{ 26137 }, /* itlb1_writes\000cpum_cf\000extended\000ITLB1 Writes. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000 */
{ 44293 }, /* l1d_l2_sourced_writes\000cpum_cf\000extended\000L1D L2 Sourced Writes. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from the Level-2 cache\000 */
{ 46483 }, /* l1d_lmem_sourced_writes\000cpum_cf\000extended\000L1D Local Memory Sourced Writes. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A directory write to the Level-1 Data Cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000 */
{ 46754 }, /* l1d_offbook_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Book L3 Sourced Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-3 cache\000 */
{ 47525 }, /* l1d_offbook_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000 */
{ 48265 }, /* l1d_offchip_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache\000 */
{ 52601 }, /* l1d_onbook_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Book Level-4 cache\000 */
{ 53579 }, /* l1d_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Chip Level-3 cache\000 */
{ 59204 }, /* l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 60444 }, /* l1i_l2_sourced_writes\000cpum_cf\000extended\000L1I L2 Sourced Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 cache\000 */
{ 62271 }, /* l1i_lmem_sourced_writes\000cpum_cf\000extended\000L1I Local Memory Sourced Writes. Unit: cpum_cf \000event=0x8e\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)\000 */
{ 62556 }, /* l1i_offbook_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Book L3 Sourced Writes. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-3 cache\000 */
{ 63348 }, /* l1i_offbook_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000 */
{ 64109 }, /* l1i_offchip_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache\000 */
{ 68556 }, /* l1i_onbook_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x88\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Book Level-4 cache\000 */
{ 69038 }, /* l1i_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Chip Level-3 cache\000 */
{ 74699 }, /* l2c_stores_sent\000cpum_cf\000extended\000L2C Stores Sent. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000Incremented by one for every store sent to Level-2 cache\000 */
{ 89393 }, /* tlb2_crste_hpage_writes\000cpum_cf\000extended\000TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000 */
{ 90412 }, /* tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000 */
{ 91639 }, /* tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000 */
};

static const struct compact_pmu_event pmu_events__cf_zec12[] = {
{ 3351 }, /* cpu_cycles\000cpum_cf\000basic\000Cycle Count. Unit: cpum_cf \000event=0\000\000\000\000\000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 24736 }, /* instructions\000cpum_cf\000basic\000Instruction Count. Unit: cpum_cf \000event=0x1\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 44119 }, /* l1d_dir_writes\000cpum_cf\000basic\000Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x4\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 58432 }, /* l1d_penalty_cycles\000cpum_cf\000basic\000Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x5\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 60020 }, /* l1i_dir_writes\000cpum_cf\000basic\000Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x2\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 74491 }, /* l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x3\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 85129 }, /* problem_state_cpu_cycles\000cpum_cf\000basic\000Problem-State Cycle Count. Unit: cpum_cf \000event=0x20\000\000\000\000\000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 85381 }, /* problem_state_instructions\000cpum_cf\000basic\000Problem-State Instruction Count. Unit: cpum_cf \000event=0x21\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 85586 }, /* problem_state_l1d_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x24\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000 */
{ 85827 }, /* problem_state_l1d_penalty_cycles\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x25\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000 */
{ 86072 }, /* problem_state_l1i_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x22\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000 */
{ 86337 }, /* problem_state_l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x23\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000 */
{ 1054 }, /* aes_blocked_cycles\000cpum_cf\000crypto\000AES Blocked Cycle Count. Unit: cpum_cf \000event=0x4f\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 1609 }, /* aes_blocked_functions\000cpum_cf\000crypto\000AES Blocked Function Count. Unit: cpum_cf \000event=0x4e\000\000\000\000\000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 2100 }, /* aes_cycles\000cpum_cf\000crypto\000AES Cycle Count. Unit: cpum_cf \000event=0x4d\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 2466 }, /* aes_functions\000cpum_cf\000crypto\000AES Function Count. Unit: cpum_cf \000event=0x4c\000\000\000\000\000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 8273 }, /* dea_blocked_cycles\000cpum_cf\000crypto\000DEA Blocked Cycle Count. Unit: cpum_cf \000event=0x4b\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 8828 }, /* dea_blocked_functions\000cpum_cf\000crypto\000DEA Blocked Function Count. Unit: cpum_cf \000event=0x4a\000\000\000\000\000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 9319 }, /* dea_cycles\000cpum_cf\000crypto\000DEA Cycle Count. Unit: cpum_cf \000event=0x49\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 9685 }, /* dea_functions\000cpum_cf\000crypto\000DEA Function Count. Unit: cpum_cf \000event=0x48\000\000\000\000\000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 82874 }, /* prng_blocked_cycles\000cpum_cf\000crypto\000PRNG Blocked Cycle Count. Unit: cpum_cf \000event=0x43\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 83495 }, /* prng_blocked_functions\000cpum_cf\000crypto\000PRNG Blocked Function Count. Unit: cpum_cf \000event=0x42\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 84053 }, /* prng_cycles\000cpum_cf\000crypto\000PRNG Cycle Count. Unit: cpum_cf \000event=0x41\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 84482 }, /* prng_functions\000cpum_cf\000crypto\000PRNG Function Count. Unit: cpum_cf \000event=0x40\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 86965 }, /* sha_blocked_cycles\000cpum_cf\000crypto\000SHA Blocked Cycle Count. Unit: cpum_cf \000event=0x47\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87512 }, /* sha_blocked_functions\000cpum_cf\000crypto\000SHA Blocked Function Count. Unit: cpum_cf \000event=0x46\000\000\000\000\000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87995 }, /* sha_cycles\000cpum_cf\000crypto\000SHA Cycle Count. Unit: cpum_cf \000event=0x45\000\000\000\000\000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 88357 }, /* sha_functions\000cpum_cf\000crypto\000SHA Function Count. Unit: cpum_cf \000event=0x44\000\000\000\000\000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 12138 }, /* dtlb1_hpage_writes\000cpum_cf\000extended\000DTLB1 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000 */
{ 12556 }, /* dtlb1_misses\000cpum_cf\000extended\000DTLB1 Misses. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000 */
{ 13245 }, /* dtlb1_writes\000cpum_cf\000extended\000DTLB1 Writes. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000 */
{ 24885 }, /* itlb1_misses\000cpum_cf\000extended\000ITLB1 Misses. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress\000 */
{ 25961 }, /* itlb1_writes\000cpum_cf\000extended\000ITLB1 Writes. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000 */
{ 44725 }, /* l1d_l2d_sourced_writes\000cpum_cf\000extended\000L1D L2D Sourced Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000 */
{ 45163 }, /* l1d_l2i_sourced_writes\000cpum_cf\000extended\000L1D L2I Sourced Writes. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 46212 }, /* l1d_lmem_sourced_writes\000cpum_cf\000extended\000L1D Local Memory Sourced Writes. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A directory write to the Level-1 Data cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000 */
{ 46991 }, /* l1d_offbook_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Book L3 Sourced Writes. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention\000 */
{ 47249 }, /* l1d_offbook_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Book L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention\000 */
{ 47762 }, /* l1d_offbook_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000 */
{ 47999 }, /* l1d_offchip_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention\000 */
{ 48510 }, /* l1d_offchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x97\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention\000 */
{ 52835 }, /* l1d_onbook_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Book Level-4 cache\000 */
{ 53069 }, /* l1d_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x90\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention\000 */
{ 54359 }, /* l1d_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from a On Chip Level-3 cache with intervention\000 */
{ 59498 }, /* l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 60663 }, /* l1i_l2i_sourced_writes\000cpum_cf\000extended\000L1I L2I Sourced Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 61986 }, /* l1i_lmem_sourced_writes\000cpum_cf\000extended\000L1I Local Memory Sourced Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A directory write to the Level-1 Instruction cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)\000 */
{ 62800 }, /* l1i_offbook_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Book L3 Sourced Writes. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention\000 */
{ 63065 }, /* l1i_offbook_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Book L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa1\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention\000 */
{ 63592 }, /* l1i_offbook_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x9d\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000 */
{ 63836 }, /* l1i_offchip_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x9a\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention\000 */
{ 64361 }, /* l1i_offchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa0\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention\000 */
{ 68797 }, /* l1i_onbook_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Book L4 Sourced Writes. Unit: cpum_cf \000event=0x9c\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Book Level-4 cache\000 */
{ 69279 }, /* l1i_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention\000 */
{ 70064 }, /* l1i_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x9f\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention\000 */
{ 89145 }, /* tlb2_crste_hpage_writes\000cpum_cf\000extended\000TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf \000event=0x8e\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000 */
{ 90230 }, /* tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000 */
{ 91478 }, /* tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000 */
{ 92098 }, /* tx_c_tabort_no_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf \000event=0xb2\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 93303 }, /* tx_c_tabort_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf \000event=0xb3\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 94672 }, /* tx_c_tend\000cpum_cf\000extended\000Completed TEND instructions in constrained TX mode. Unit: cpum_cf \000event=0x9e\000\000\000\000\000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 94861 }, /* tx_nc_tabort\000cpum_cf\000extended\000Aborted transactions in non-constrained TX mode. Unit: cpum_cf \000event=0xb1\000\000\000\000\000\000A transaction abort has occurred in a nonconstrained transactional-execution mode\000 */
{ 95828 }, /* tx_nc_tend\000cpum_cf\000extended\000Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf \000event=0x95\000\000\000\000\000\000A TEND instruction has completed in a nonconstrained transactional-execution mode\000 */
};

static const struct compact_pmu_event pmu_metrics__cf_zec12[] = {
{ 91977 }, /* transaction\000\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000Transaction count\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__cf_z10[] = {
{ 3351 }, /* cpu_cycles\000cpum_cf\000basic\000Cycle Count. Unit: cpum_cf \000event=0\000\000\000\000\000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 24736 }, /* instructions\000cpum_cf\000basic\000Instruction Count. Unit: cpum_cf \000event=0x1\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 44119 }, /* l1d_dir_writes\000cpum_cf\000basic\000Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x4\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 58432 }, /* l1d_penalty_cycles\000cpum_cf\000basic\000Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x5\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 60020 }, /* l1i_dir_writes\000cpum_cf\000basic\000Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x2\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 74491 }, /* l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x3\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 85129 }, /* problem_state_cpu_cycles\000cpum_cf\000basic\000Problem-State Cycle Count. Unit: cpum_cf \000event=0x20\000\000\000\000\000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 85381 }, /* problem_state_instructions\000cpum_cf\000basic\000Problem-State Instruction Count. Unit: cpum_cf \000event=0x21\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 85586 }, /* problem_state_l1d_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x24\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000 */
{ 85827 }, /* problem_state_l1d_penalty_cycles\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x25\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000 */
{ 86072 }, /* problem_state_l1i_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x22\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000 */
{ 86337 }, /* problem_state_l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x23\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000 */
{ 1054 }, /* aes_blocked_cycles\000cpum_cf\000crypto\000AES Blocked Cycle Count. Unit: cpum_cf \000event=0x4f\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 1609 }, /* aes_blocked_functions\000cpum_cf\000crypto\000AES Blocked Function Count. Unit: cpum_cf \000event=0x4e\000\000\000\000\000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 2100 }, /* aes_cycles\000cpum_cf\000crypto\000AES Cycle Count. Unit: cpum_cf \000event=0x4d\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 2466 }, /* aes_functions\000cpum_cf\000crypto\000AES Function Count. Unit: cpum_cf \000event=0x4c\000\000\000\000\000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 8273 }, /* dea_blocked_cycles\000cpum_cf\000crypto\000DEA Blocked Cycle Count. Unit: cpum_cf \000event=0x4b\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 8828 }, /* dea_blocked_functions\000cpum_cf\000crypto\000DEA Blocked Function Count. Unit: cpum_cf \000event=0x4a\000\000\000\000\000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 9319 }, /* dea_cycles\000cpum_cf\000crypto\000DEA Cycle Count. Unit: cpum_cf \000event=0x49\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 9685 }, /* dea_functions\000cpum_cf\000crypto\000DEA Function Count. Unit: cpum_cf \000event=0x48\000\000\000\000\000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 82874 }, /* prng_blocked_cycles\000cpum_cf\000crypto\000PRNG Blocked Cycle Count. Unit: cpum_cf \000event=0x43\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 83495 }, /* prng_blocked_functions\000cpum_cf\000crypto\000PRNG Blocked Function Count. Unit: cpum_cf \000event=0x42\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 84053 }, /* prng_cycles\000cpum_cf\000crypto\000PRNG Cycle Count. Unit: cpum_cf \000event=0x41\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 84482 }, /* prng_functions\000cpum_cf\000crypto\000PRNG Function Count. Unit: cpum_cf \000event=0x40\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 86965 }, /* sha_blocked_cycles\000cpum_cf\000crypto\000SHA Blocked Cycle Count. Unit: cpum_cf \000event=0x47\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87512 }, /* sha_blocked_functions\000cpum_cf\000crypto\000SHA Blocked Function Count. Unit: cpum_cf \000event=0x46\000\000\000\000\000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87995 }, /* sha_cycles\000cpum_cf\000crypto\000SHA Cycle Count. Unit: cpum_cf \000event=0x45\000\000\000\000\000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 88357 }, /* sha_functions\000cpum_cf\000crypto\000SHA Function Count. Unit: cpum_cf \000event=0x44\000\000\000\000\000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 12902 }, /* dtlb1_misses\000cpum_cf\000extended\000DTLB1 Misses. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle an DTLB1 miss is in progress\000 */
{ 13414 }, /* dtlb1_writes\000cpum_cf\000extended\000DTLB1 Writes. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000 */
{ 25426 }, /* itlb1_misses\000cpum_cf\000extended\000ITLB1 Misses. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress\000 */
{ 25783 }, /* itlb1_writes\000cpum_cf\000extended\000ITLB1 Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000A translation entry has been written into the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000 */
{ 44505 }, /* l1d_l2_sourced_writes\000cpum_cf\000extended\000L1D L2 Sourced Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from the Level-2 (L1.5) cache\000 */
{ 45389 }, /* l1d_l3_local_writes\000cpum_cf\000extended\000L1D L3 Local Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the installed cache line was source from the Level-3 cache that is on the same book as the Data cache (Local L2 cache)\000 */
{ 45657 }, /* l1d_l3_remote_writes\000cpum_cf\000extended\000L1D L3 Remote Writes. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Data cache (Remote L2 cache)\000 */
{ 45931 }, /* l1d_lmem_sourced_writes\000cpum_cf\000extended\000L1D Local Memory Sourced Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000 */
{ 58910 }, /* l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x88\000\000\000\000\000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 59792 }, /* l1i_cacheline_invalidates\000cpum_cf\000extended\000L1I Cacheline Invalidates. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A cache line in the Level-1 Instruction Cache has been invalidated by a store on the same CPU as the Level-1 Instruction Cache\000 */
{ 60218 }, /* l1i_l2_sourced_writes\000cpum_cf\000extended\000L1I L2 Sourced Writes. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 (L1.5) cache\000 */
{ 61129 }, /* l1i_l3_local_writes\000cpum_cf\000extended\000L1I L3 Local Writes. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from the Level-3 cache that is on the same book as the Instruction cache (Local L2 cache)\000 */
{ 61412 }, /* l1i_l3_remote_writes\000cpum_cf\000extended\000L1I L3 Remote Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Instruction cache (Remote L2 cache)\000 */
{ 61700 }, /* l1i_lmem_sourced_writes\000cpum_cf\000extended\000L1I Local Memory Sourced Writes. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the s ame book as the Instruction cache (Local Memory)\000 */
{ 74837 }, /* l2c_stores_sent\000cpum_cf\000extended\000L2C Stores Sent. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000Incremented by one for every store sent to Level-2 (L1.5) cache\000 */
{ 89145 }, /* tlb2_crste_hpage_writes\000cpum_cf\000extended\000TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf \000event=0x8e\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000 */
{ 90048 }, /* tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000 */
{ 91317 }, /* tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000 */
};

static const struct compact_pmu_event pmu_events__cf_z13[] = {
{ 3351 }, /* cpu_cycles\000cpum_cf\000basic\000Cycle Count. Unit: cpum_cf \000event=0\000\000\000\000\000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 24736 }, /* instructions\000cpum_cf\000basic\000Instruction Count. Unit: cpum_cf \000event=0x1\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 44119 }, /* l1d_dir_writes\000cpum_cf\000basic\000Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x4\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 58432 }, /* l1d_penalty_cycles\000cpum_cf\000basic\000Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x5\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 60020 }, /* l1i_dir_writes\000cpum_cf\000basic\000Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x2\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 74491 }, /* l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x3\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 85129 }, /* problem_state_cpu_cycles\000cpum_cf\000basic\000Problem-State Cycle Count. Unit: cpum_cf \000event=0x20\000\000\000\000\000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 85381 }, /* problem_state_instructions\000cpum_cf\000basic\000Problem-State Instruction Count. Unit: cpum_cf \000event=0x21\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 85586 }, /* problem_state_l1d_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x24\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000 */
{ 85827 }, /* problem_state_l1d_penalty_cycles\000cpum_cf\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x25\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000 */
{ 86072 }, /* problem_state_l1i_dir_writes\000cpum_cf\000basic\000Problem-State Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x22\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000 */
{ 86337 }, /* problem_state_l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x23\000\000\000\000\000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000 */
{ 1054 }, /* aes_blocked_cycles\000cpum_cf\000crypto\000AES Blocked Cycle Count. Unit: cpum_cf \000event=0x4f\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 1609 }, /* aes_blocked_functions\000cpum_cf\000crypto\000AES Blocked Function Count. Unit: cpum_cf \000event=0x4e\000\000\000\000\000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 2100 }, /* aes_cycles\000cpum_cf\000crypto\000AES Cycle Count. Unit: cpum_cf \000event=0x4d\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 2466 }, /* aes_functions\000cpum_cf\000crypto\000AES Function Count. Unit: cpum_cf \000event=0x4c\000\000\000\000\000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 8273 }, /* dea_blocked_cycles\000cpum_cf\000crypto\000DEA Blocked Cycle Count. Unit: cpum_cf \000event=0x4b\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 8828 }, /* dea_blocked_functions\000cpum_cf\000crypto\000DEA Blocked Function Count. Unit: cpum_cf \000event=0x4a\000\000\000\000\000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 9319 }, /* dea_cycles\000cpum_cf\000crypto\000DEA Cycle Count. Unit: cpum_cf \000event=0x49\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 9685 }, /* dea_functions\000cpum_cf\000crypto\000DEA Function Count. Unit: cpum_cf \000event=0x48\000\000\000\000\000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 82874 }, /* prng_blocked_cycles\000cpum_cf\000crypto\000PRNG Blocked Cycle Count. Unit: cpum_cf \000event=0x43\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 83495 }, /* prng_blocked_functions\000cpum_cf\000crypto\000PRNG Blocked Function Count. Unit: cpum_cf \000event=0x42\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 84053 }, /* prng_cycles\000cpum_cf\000crypto\000PRNG Cycle Count. Unit: cpum_cf \000event=0x41\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 84482 }, /* prng_functions\000cpum_cf\000crypto\000PRNG Function Count. Unit: cpum_cf \000event=0x40\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 86965 }, /* sha_blocked_cycles\000cpum_cf\000crypto\000SHA Blocked Cycle Count. Unit: cpum_cf \000event=0x47\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87512 }, /* sha_blocked_functions\000cpum_cf\000crypto\000SHA Blocked Function Count. Unit: cpum_cf \000event=0x46\000\000\000\000\000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87995 }, /* sha_cycles\000cpum_cf\000crypto\000SHA Cycle Count. Unit: cpum_cf \000event=0x45\000\000\000\000\000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 88357 }, /* sha_functions\000cpum_cf\000crypto\000SHA Function Count. Unit: cpum_cf \000event=0x44\000\000\000\000\000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 11720 }, /* dtlb1_gpage_writes\000cpum_cf\000extended\000DTLB1 Two-Gigabyte Page Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a two-gigabyte page\000 */
{ 11929 }, /* dtlb1_hpage_writes\000cpum_cf\000extended\000DTLB1 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000 */
{ 12729 }, /* dtlb1_misses\000cpum_cf\000extended\000DTLB1 Misses. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000 */
{ 13076 }, /* dtlb1_writes\000cpum_cf\000extended\000DTLB1 Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000 */
{ 25245 }, /* itlb1_misses\000cpum_cf\000extended\000ITLB1 Misses. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress\000 */
{ 25607 }, /* itlb1_writes\000cpum_cf\000extended\000ITLB1 Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000 */
{ 43779 }, /* l1c_tlb1_misses\000cpum_cf\000extended\000L1C TLB1 Misses. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000Increments by one for any cycle where a Level-1 cache or Level-1 TLB miss is in progress\000 */
{ 44944 }, /* l1d_l2d_sourced_writes\000cpum_cf\000extended\000L1D L2D Sourced Writes. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000 */
{ 49590 }, /* l1d_offdrawer_fcol_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes. Unit: cpum_cf \000event=0x9d\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention\000 */
{ 49881 }, /* l1d_offdrawer_fcol_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x9c\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention\000 */
{ 50190 }, /* l1d_offdrawer_fcol_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache\000 */
{ 51246 }, /* l1d_offdrawer_mem_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0xa0\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 51725 }, /* l1d_offdrawer_scol_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Same-Column L3 Sourced Writes. Unit: cpum_cf \000event=0x9a\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention\000 */
{ 52018 }, /* l1d_offdrawer_scol_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Drawer Same-Column L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention\000 */
{ 52329 }, /* l1d_offdrawer_scol_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Same-Column L4 Sourced Writes. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache\000 */
{ 53324 }, /* l1d_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x90\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 53813 }, /* l1d_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 54941 }, /* l1d_onchip_mem_sourced_writes\000cpum_cf\000extended\000L1D On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0xa1\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 56189 }, /* l1d_ondrawer_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0x97\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention\000 */
{ 56450 }, /* l1d_ondrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention\000 */
{ 56729 }, /* l1d_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0x95\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache\000 */
{ 57206 }, /* l1d_ondrawer_mem_sourced_writes\000cpum_cf\000extended\000L1D On-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0x9f\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 57441 }, /* l1d_onnode_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Node L3 Sourced Writes. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention\000 */
{ 57696 }, /* l1d_onnode_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Node L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention\000 */
{ 57969 }, /* l1d_onnode_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Node L4 Sourced Writes. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-4 cache\000 */
{ 58203 }, /* l1d_onnode_mem_sourced_writes\000cpum_cf\000extended\000L1D On-Node Memory Sourced Writes. Unit: cpum_cf \000event=0x9e\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Node memory\000 */
{ 58616 }, /* l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 60896 }, /* l1i_l2i_sourced_writes\000cpum_cf\000extended\000L1I L2I Sourced Writes. Unit: cpum_cf \000event=0x88\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 65469 }, /* l1i_offdrawer_fcol_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Far-Column L3 Sourced Writes. Unit: cpum_cf \000event=0xaf\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention\000 */
{ 65767 }, /* l1i_offdrawer_fcol_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Drawer Far-Column L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xae\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention\000 */
{ 66083 }, /* l1i_offdrawer_fcol_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Far-Column L4 Sourced Writes. Unit: cpum_cf \000event=0xad\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache\000 */
{ 67167 }, /* l1i_offdrawer_mem_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0xb2\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 67659 }, /* l1i_offdrawer_scol_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Same-Column L3 Sourced Writes. Unit: cpum_cf \000event=0xac\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention\000 */
{ 67959 }, /* l1i_offdrawer_scol_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Drawer Same-Column L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xab\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention\000 */
{ 68277 }, /* l1i_offdrawer_scol_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Same-Column L4 Sourced Writes. Unit: cpum_cf \000event=0xaa\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache\000 */
{ 69802 }, /* l1i_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0xa2\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 70344 }, /* l1i_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa3\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention\000 */
{ 70903 }, /* l1i_onchip_mem_sourced_writes\000cpum_cf\000extended\000L1I On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0xb3\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 72185 }, /* l1i_ondrawer_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0xa9\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention\000 */
{ 72453 }, /* l1i_ondrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa8\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention\000 */
{ 72739 }, /* l1i_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0xa7\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache\000 */
{ 73230 }, /* l1i_ondrawer_mem_sourced_writes\000cpum_cf\000extended\000L1I On-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0xb1\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 73472 }, /* l1i_onnode_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Node L3 Sourced Writes. Unit: cpum_cf \000event=0xa6\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention\000 */
{ 73734 }, /* l1i_onnode_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Node L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa5\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention\000 */
{ 74014 }, /* l1i_onnode_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L4 Sourced Writes. Unit: cpum_cf \000event=0xa4\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-4 cache\000 */
{ 74255 }, /* l1i_onnode_mem_sourced_writes\000cpum_cf\000extended\000L1I On-Node Memory Sourced Writes. Unit: cpum_cf \000event=0xb0\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Node memory\000 */
{ 75205 }, /* mt_diag_cycles_one_thr_active\000cpum_cf\000extended\000Cycle count with one thread active. Unit: cpum_cf \000event=0x1c0\000\000\000\000\000\000Cycle count with one thread active\000 */
{ 75355 }, /* mt_diag_cycles_two_thr_active\000cpum_cf\000extended\000Cycle count with two threads active. Unit: cpum_cf \000event=0x1c1\000\000\000\000\000\000Cycle count with two threads active\000 */
{ 88895 }, /* tlb2_crste_hpage_writes\000cpum_cf\000extended\000TLB2 CRSTE One-Megabyte Page Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays for a one-megabyte large page translation\000 */
{ 89864 }, /* tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays\000 */
{ 90992 }, /* tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000 */
{ 92408 }, /* tx_c_tabort_no_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf \000event=0xdb\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 93598 }, /* tx_c_tabort_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf \000event=0xdc\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 94483 }, /* tx_c_tend\000cpum_cf\000extended\000Completed TEND instructions in constrained TX mode. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 95053 }, /* tx_nc_tabort\000cpum_cf\000extended\000Aborted transactions in non-constrained TX mode. Unit: cpum_cf \000event=0xda\000\000\000\000\000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000 */
{ 95630 }, /* tx_nc_tend\000cpum_cf\000extended\000Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000 */
};

static const struct compact_pmu_event pmu_metrics__cf_z13[] = {
{ 91977 }, /* transaction\000\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000Transaction count\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__cf_z14[] = {
{ 3351 }, /* cpu_cycles\000cpum_cf\000basic\000Cycle Count. Unit: cpum_cf \000event=0\000\000\000\000\000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 24736 }, /* instructions\000cpum_cf\000basic\000Instruction Count. Unit: cpum_cf \000event=0x1\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 44119 }, /* l1d_dir_writes\000cpum_cf\000basic\000Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x4\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 58432 }, /* l1d_penalty_cycles\000cpum_cf\000basic\000Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x5\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 60020 }, /* l1i_dir_writes\000cpum_cf\000basic\000Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x2\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 74491 }, /* l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x3\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 85129 }, /* problem_state_cpu_cycles\000cpum_cf\000basic\000Problem-State Cycle Count. Unit: cpum_cf \000event=0x20\000\000\000\000\000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 85381 }, /* problem_state_instructions\000cpum_cf\000basic\000Problem-State Instruction Count. Unit: cpum_cf \000event=0x21\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 1054 }, /* aes_blocked_cycles\000cpum_cf\000crypto\000AES Blocked Cycle Count. Unit: cpum_cf \000event=0x4f\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 1609 }, /* aes_blocked_functions\000cpum_cf\000crypto\000AES Blocked Function Count. Unit: cpum_cf \000event=0x4e\000\000\000\000\000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 2100 }, /* aes_cycles\000cpum_cf\000crypto\000AES Cycle Count. Unit: cpum_cf \000event=0x4d\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 2466 }, /* aes_functions\000cpum_cf\000crypto\000AES Function Count. Unit: cpum_cf \000event=0x4c\000\000\000\000\000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 8273 }, /* dea_blocked_cycles\000cpum_cf\000crypto\000DEA Blocked Cycle Count. Unit: cpum_cf \000event=0x4b\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 8828 }, /* dea_blocked_functions\000cpum_cf\000crypto\000DEA Blocked Function Count. Unit: cpum_cf \000event=0x4a\000\000\000\000\000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 9319 }, /* dea_cycles\000cpum_cf\000crypto\000DEA Cycle Count. Unit: cpum_cf \000event=0x49\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 9685 }, /* dea_functions\000cpum_cf\000crypto\000DEA Function Count. Unit: cpum_cf \000event=0x48\000\000\000\000\000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 82874 }, /* prng_blocked_cycles\000cpum_cf\000crypto\000PRNG Blocked Cycle Count. Unit: cpum_cf \000event=0x43\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 83495 }, /* prng_blocked_functions\000cpum_cf\000crypto\000PRNG Blocked Function Count. Unit: cpum_cf \000event=0x42\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 84053 }, /* prng_cycles\000cpum_cf\000crypto\000PRNG Cycle Count. Unit: cpum_cf \000event=0x41\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 84482 }, /* prng_functions\000cpum_cf\000crypto\000PRNG Function Count. Unit: cpum_cf \000event=0x40\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 86965 }, /* sha_blocked_cycles\000cpum_cf\000crypto\000SHA Blocked Cycle Count. Unit: cpum_cf \000event=0x47\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87512 }, /* sha_blocked_functions\000cpum_cf\000crypto\000SHA Blocked Function Count. Unit: cpum_cf \000event=0x46\000\000\000\000\000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87995 }, /* sha_cycles\000cpum_cf\000crypto\000SHA Cycle Count. Unit: cpum_cf \000event=0x45\000\000\000\000\000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 88357 }, /* sha_functions\000cpum_cf\000crypto\000SHA Function Count. Unit: cpum_cf \000event=0x44\000\000\000\000\000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 2622 }, /* bcd_dfp_execution_slots\000cpum_cf\000extended\000BCD DFP Execution Slots. Unit: cpum_cf \000event=0xe0\000\000\000\000\000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000 */
{ 9841 }, /* decimal_instructions\000cpum_cf\000extended\000Decimal Instructions. Unit: cpum_cf \000event=0xe2\000\000\000\000\000\000Decimal instructions dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000 */
{ 13752 }, /* dtlb2_gpage_writes\000cpum_cf\000extended\000DTLB2 Two-Gigabyte Page Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A translation entry for a two-gigabyte page was written into the Level-2 TLB\000 */
{ 13928 }, /* dtlb2_hpage_writes\000cpum_cf\000extended\000DTLB2 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page or a Last Host Translation was done\000 */
{ 14746 }, /* dtlb2_misses\000cpum_cf\000extended\000DTLB2 Misses. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on prior machines\000 */
{ 15342 }, /* dtlb2_writes\000cpum_cf\000extended\000DTLB2 Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the data cache. This is a replacement for what was provided for the DTLB on prior machines\000 */
{ 26648 }, /* itlb2_misses\000cpum_cf\000extended\000ITLB2 Misses. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on prior machines\000 */
{ 26967 }, /* itlb2_writes\000cpum_cf\000extended\000ITLB2 Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on prior machines\000 */
{ 43949 }, /* l1c_tlb2_misses\000cpum_cf\000extended\000L1C TLB2 Misses. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress\000 */
{ 44944 }, /* l1d_l2d_sourced_writes\000cpum_cf\000extended\000L1D L2D Sourced Writes. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000 */
{ 48794 }, /* l1d_offcluster_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000 */
{ 49061 }, /* l1d_offcluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000 */
{ 49346 }, /* l1d_offcluster_memory_sourced_writes\000cpum_cf\000extended\000L1D Off-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0x97\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Cluster memory\000 */
{ 50460 }, /* l1d_offdrawer_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000 */
{ 50724 }, /* l1d_offdrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000 */
{ 51006 }, /* l1d_offdrawer_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0x9d\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000 */
{ 51484 }, /* l1d_offdrawer_memory_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0x9a\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 53324 }, /* l1d_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x90\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 54086 }, /* l1d_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 54631 }, /* l1d_onchip_l3_sourced_writes_ro\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes read-only. Unit: cpum_cf \000event=0x9e\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip L3 but a read-only invalidate was done to remove other copies of the cache line\000 */
{ 55170 }, /* l1d_onchip_memory_sourced_writes\000cpum_cf\000extended\000L1D On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 55402 }, /* l1d_oncluster_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Cluster Level-3 cache without intervention\000 */
{ 55663 }, /* l1d_oncluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x95\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache with intervention\000 */
{ 55945 }, /* l1d_oncluster_memory_sourced_writes\000cpum_cf\000extended\000L1D On-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster memory\000 */
{ 56969 }, /* l1d_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0x9c\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000 */
{ 58616 }, /* l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 60896 }, /* l1i_l2i_sourced_writes\000cpum_cf\000extended\000L1I L2I Sourced Writes. Unit: cpum_cf \000event=0x88\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 64652 }, /* l1i_offcluster_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0xa8\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000 */
{ 64926 }, /* l1i_offcluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xaa\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000 */
{ 65218 }, /* l1i_offcluster_memory_sourced_writes\000cpum_cf\000extended\000L1I Off-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0xa9\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Cluster memory\000 */
{ 66360 }, /* l1i_offdrawer_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0xab\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000 */
{ 66631 }, /* l1i_offdrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xad\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000 */
{ 66920 }, /* l1i_offdrawer_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0xaf\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000 */
{ 67411 }, /* l1i_offdrawer_memory_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0xac\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 69541 }, /* l1i_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0xa2\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 70624 }, /* l1i_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa4\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 71139 }, /* l1i_onchip_memory_sourced_writes\000cpum_cf\000extended\000L1I On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0xa3\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from On-Chip memory\000 */
{ 71377 }, /* l1i_oncluster_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0xa5\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache without intervention\000 */
{ 71648 }, /* l1i_oncluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa7\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Cluster Level-3 cache with intervention\000 */
{ 71934 }, /* l1i_oncluster_memory_sourced_writes\000cpum_cf\000extended\000L1I On-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0xa6\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster memory\000 */
{ 72986 }, /* l1i_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0xae\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000 */
{ 75079 }, /* last_host_translations\000cpum_cf\000extended\000Last host translation done. Unit: cpum_cf \000event=0xe8\000\000\000\000\000\000Last Host Translation done\000 */
{ 75205 }, /* mt_diag_cycles_one_thr_active\000cpum_cf\000extended\000Cycle count with one thread active. Unit: cpum_cf \000event=0x1c0\000\000\000\000\000\000Cycle count with one thread active\000 */
{ 75355 }, /* mt_diag_cycles_two_thr_active\000cpum_cf\000extended\000Cycle count with two threads active. Unit: cpum_cf \000event=0x1c1\000\000\000\000\000\000Cycle count with two threads active\000 */
{ 89641 }, /* tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000 */
{ 90845 }, /* tlb2_engines_busy\000cpum_cf\000extended\000TLB2 Engines Busy. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000The number of Level-2 TLB translation engines busy in a cycle\000 */
{ 91153 }, /* tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000 */
{ 92718 }, /* tx_c_tabort_no_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf \000event=0xf4\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 93893 }, /* tx_c_tabort_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf \000event=0xf5\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 94483 }, /* tx_c_tend\000cpum_cf\000extended\000Completed TEND instructions in constrained TX mode. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 95246 }, /* tx_nc_tabort\000cpum_cf\000extended\000Aborted transactions in non-constrained TX mode. Unit: cpum_cf \000event=0xf3\000\000\000\000\000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000 */
{ 95630 }, /* tx_nc_tend\000cpum_cf\000extended\000Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000 */
{ 97164 }, /* vx_bcd_execution_slots\000cpum_cf\000extended\000VX BCD Execution Slots. Unit: cpum_cf \000event=0xe1\000\000\000\000\000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMPVMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOPVCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVDVCVDG\000 */
};

static const struct compact_pmu_event pmu_metrics__cf_z14[] = {
{ 91977 }, /* transaction\000\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000Transaction count\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__cf_z15[] = {
{ 3351 }, /* cpu_cycles\000cpum_cf\000basic\000Cycle Count. Unit: cpum_cf \000event=0\000\000\000\000\000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 24736 }, /* instructions\000cpum_cf\000basic\000Instruction Count. Unit: cpum_cf \000event=0x1\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 44119 }, /* l1d_dir_writes\000cpum_cf\000basic\000Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x4\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 58432 }, /* l1d_penalty_cycles\000cpum_cf\000basic\000Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x5\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 60020 }, /* l1i_dir_writes\000cpum_cf\000basic\000Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x2\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 74491 }, /* l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x3\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 85129 }, /* problem_state_cpu_cycles\000cpum_cf\000basic\000Problem-State Cycle Count. Unit: cpum_cf \000event=0x20\000\000\000\000\000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 85381 }, /* problem_state_instructions\000cpum_cf\000basic\000Problem-State Instruction Count. Unit: cpum_cf \000event=0x21\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 780 }, /* aes_blocked_cycles\000cpum_cf\000crypto6\000AES Blocked Cycle Count. Unit: cpum_cf \000event=0x4f\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 1327 }, /* aes_blocked_functions\000cpum_cf\000crypto6\000AES Blocked Function Count. Unit: cpum_cf \000event=0x4e\000\000\000\000\000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 1890 }, /* aes_cycles\000cpum_cf\000crypto6\000AES Cycle Count. Unit: cpum_cf \000event=0x4d\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 2309 }, /* aes_functions\000cpum_cf\000crypto6\000AES Function Count. Unit: cpum_cf \000event=0x4c\000\000\000\000\000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 7999 }, /* dea_blocked_cycles\000cpum_cf\000crypto6\000DEA Blocked Cycle Count. Unit: cpum_cf \000event=0x4b\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 8546 }, /* dea_blocked_functions\000cpum_cf\000crypto6\000DEA Blocked Function Count. Unit: cpum_cf \000event=0x4a\000\000\000\000\000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 9109 }, /* dea_cycles\000cpum_cf\000crypto6\000DEA Cycle Count. Unit: cpum_cf \000event=0x49\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 9528 }, /* dea_functions\000cpum_cf\000crypto6\000DEA Function Count. Unit: cpum_cf \000event=0x48\000\000\000\000\000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 15614 }, /* ecc_blocked_cycles_count\000cpum_cf\000crypto6\000ECC Blocked Cycles Count. Unit: cpum_cf \000event=0x53\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the elliptic-curve cryptography (ECC) functions issued by the CPU because the ECC coprocessor is busy performing a function issued by another CPU\000 */
{ 15921 }, /* ecc_blocked_function_count\000cpum_cf\000crypto6\000Ecc Blocked Function Count. Unit: cpum_cf \000event=0x52\000\000\000\000\000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions that are issued by the CPU and are blocked because the ECC coprocessor is busy performing a function issued by another CPU\000 */
{ 16234 }, /* ecc_cycles_count\000cpum_cf\000crypto6\000ECC Cycles Count. Unit: cpum_cf \000event=0x51\000\000\000\000\000\000This counter counts the total number of CPU cycles when the ECC coprocessor is busy performing the elliptic-curve cryptography (ECC) functions issued by the CPU\000 */
{ 16477 }, /* ecc_function_count\000cpum_cf\000crypto6\000ECC Function Count. Unit: cpum_cf \000event=0x50\000\000\000\000\000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions issued by the CPU\000 */
{ 82567 }, /* prng_blocked_cycles\000cpum_cf\000crypto6\000PRNG Blocked Cycle Count. Unit: cpum_cf \000event=0x43\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 83180 }, /* prng_blocked_functions\000cpum_cf\000crypto6\000PRNG Blocked Function Count. Unit: cpum_cf \000event=0x42\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 83809 }, /* prng_cycles\000cpum_cf\000crypto6\000PRNG Cycle Count. Unit: cpum_cf \000event=0x41\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 84296 }, /* prng_functions\000cpum_cf\000crypto6\000PRNG Function Count. Unit: cpum_cf \000event=0x40\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 86695 }, /* sha_blocked_cycles\000cpum_cf\000crypto6\000SHA Blocked Cycle Count. Unit: cpum_cf \000event=0x47\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87234 }, /* sha_blocked_functions\000cpum_cf\000crypto6\000SHA Blocked Function Count. Unit: cpum_cf \000event=0x46\000\000\000\000\000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87789 }, /* sha_cycles\000cpum_cf\000crypto6\000SHA Cycle Count. Unit: cpum_cf \000event=0x45\000\000\000\000\000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 88200 }, /* sha_functions\000cpum_cf\000crypto6\000SHA Function Count. Unit: cpum_cf \000event=0x44\000\000\000\000\000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 2622 }, /* bcd_dfp_execution_slots\000cpum_cf\000extended\000BCD DFP Execution Slots. Unit: cpum_cf \000event=0xe0\000\000\000\000\000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000 */
{ 9841 }, /* decimal_instructions\000cpum_cf\000extended\000Decimal Instructions. Unit: cpum_cf \000event=0xe2\000\000\000\000\000\000Decimal instructions dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000 */
{ 10224 }, /* dflt_access\000cpum_cf\000extended\000Cycles CPU spent obtaining access to Deflate unit. Unit: cpum_cf \000event=0xf7\000\000\000\000\000\000Cycles CPU spent obtaining access to Deflate unit\000 */
{ 10546 }, /* dflt_cc\000cpum_cf\000extended\000Increments DEFLATE CONVERSION CALL. Unit: cpum_cf \000event=0x108\000\000\000\000\000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed\000 */
{ 10878 }, /* dflt_ccfinish\000cpum_cf\000extended\000Increments completed DEFLATE CONVERSION CALL. Unit: cpum_cf \000event=0x109\000\000\000\000\000\000 Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2 complete\000 */
{ 11332 }, /* dflt_cycles\000cpum_cf\000extended\000Cycles CPU is using Deflate unit. Unit: cpum_cf \000event=0xfc\000\000\000\000\000\000Cycles CPU is using Deflate unit\000 */
{ 13752 }, /* dtlb2_gpage_writes\000cpum_cf\000extended\000DTLB2 Two-Gigabyte Page Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A translation entry for a two-gigabyte page was written into the Level-2 TLB\000 */
{ 14193 }, /* dtlb2_hpage_writes\000cpum_cf\000extended\000DTLB2 One-Megabyte Page Writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page\000 */
{ 14746 }, /* dtlb2_misses\000cpum_cf\000extended\000DTLB2 Misses. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on prior machines\000 */
{ 15342 }, /* dtlb2_writes\000cpum_cf\000extended\000DTLB2 Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the data cache. This is a replacement for what was provided for the DTLB on prior machines\000 */
{ 26648 }, /* itlb2_misses\000cpum_cf\000extended\000ITLB2 Misses. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on prior machines\000 */
{ 26967 }, /* itlb2_writes\000cpum_cf\000extended\000ITLB2 Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on prior machines\000 */
{ 43949 }, /* l1c_tlb2_misses\000cpum_cf\000extended\000L1C TLB2 Misses. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress\000 */
{ 44944 }, /* l1d_l2d_sourced_writes\000cpum_cf\000extended\000L1D L2D Sourced Writes. Unit: cpum_cf \000event=0x85\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000 */
{ 48794 }, /* l1d_offcluster_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000 */
{ 49061 }, /* l1d_offcluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000 */
{ 49346 }, /* l1d_offcluster_memory_sourced_writes\000cpum_cf\000extended\000L1D Off-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0x97\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Cluster memory\000 */
{ 50460 }, /* l1d_offdrawer_l3_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000 */
{ 50724 }, /* l1d_offdrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000 */
{ 51006 }, /* l1d_offdrawer_l4_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0x9d\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000 */
{ 51484 }, /* l1d_offdrawer_memory_sourced_writes\000cpum_cf\000extended\000L1D Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0x9a\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 53324 }, /* l1d_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0x90\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 54086 }, /* l1d_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 54631 }, /* l1d_onchip_l3_sourced_writes_ro\000cpum_cf\000extended\000L1D On-Chip L3 Sourced Writes read-only. Unit: cpum_cf \000event=0x9e\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip L3 but a read-only invalidate was done to remove other copies of the cache line\000 */
{ 55170 }, /* l1d_onchip_memory_sourced_writes\000cpum_cf\000extended\000L1D On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 55402 }, /* l1d_oncluster_l3_sourced_writes\000cpum_cf\000extended\000L1D On-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Cluster Level-3 cache without intervention\000 */
{ 55663 }, /* l1d_oncluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1D On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0x95\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache with intervention\000 */
{ 55945 }, /* l1d_oncluster_memory_sourced_writes\000cpum_cf\000extended\000L1D On-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster memory\000 */
{ 56969 }, /* l1d_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1D On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0x9c\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000 */
{ 58616 }, /* l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 60896 }, /* l1i_l2i_sourced_writes\000cpum_cf\000extended\000L1I L2I Sourced Writes. Unit: cpum_cf \000event=0x88\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 64652 }, /* l1i_offcluster_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0xa8\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000 */
{ 64926 }, /* l1i_offcluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xaa\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000 */
{ 65218 }, /* l1i_offcluster_memory_sourced_writes\000cpum_cf\000extended\000L1I Off-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0xa9\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Cluster memory\000 */
{ 66360 }, /* l1i_offdrawer_l3_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer L3 Sourced Writes. Unit: cpum_cf \000event=0xab\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000 */
{ 66631 }, /* l1i_offdrawer_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I Off-Drawer L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xad\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000 */
{ 66920 }, /* l1i_offdrawer_l4_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0xaf\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000 */
{ 67411 }, /* l1i_offdrawer_memory_sourced_writes\000cpum_cf\000extended\000L1I Off-Drawer Memory Sourced Writes. Unit: cpum_cf \000event=0xac\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 69541 }, /* l1i_onchip_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes. Unit: cpum_cf \000event=0xa2\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 70624 }, /* l1i_onchip_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Chip L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa4\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 71139 }, /* l1i_onchip_memory_sourced_writes\000cpum_cf\000extended\000L1I On-Chip Memory Sourced Writes. Unit: cpum_cf \000event=0xa3\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from On-Chip memory\000 */
{ 71377 }, /* l1i_oncluster_l3_sourced_writes\000cpum_cf\000extended\000L1I On-Cluster L3 Sourced Writes. Unit: cpum_cf \000event=0xa5\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache without intervention\000 */
{ 71648 }, /* l1i_oncluster_l3_sourced_writes_iv\000cpum_cf\000extended\000L1I On-Cluster L3 Sourced Writes with Intervention. Unit: cpum_cf \000event=0xa7\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Cluster Level-3 cache with intervention\000 */
{ 71934 }, /* l1i_oncluster_memory_sourced_writes\000cpum_cf\000extended\000L1I On-Cluster Memory Sourced Writes. Unit: cpum_cf \000event=0xa6\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster memory\000 */
{ 72986 }, /* l1i_ondrawer_l4_sourced_writes\000cpum_cf\000extended\000L1I On-Drawer L4 Sourced Writes. Unit: cpum_cf \000event=0xae\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000 */
{ 75079 }, /* last_host_translations\000cpum_cf\000extended\000Last host translation done. Unit: cpum_cf \000event=0xe8\000\000\000\000\000\000Last Host Translation done\000 */
{ 75205 }, /* mt_diag_cycles_one_thr_active\000cpum_cf\000extended\000Cycle count with one thread active. Unit: cpum_cf \000event=0x1c0\000\000\000\000\000\000Cycle count with one thread active\000 */
{ 75355 }, /* mt_diag_cycles_two_thr_active\000cpum_cf\000extended\000Cycle count with two threads active. Unit: cpum_cf \000event=0x1c1\000\000\000\000\000\000Cycle count with two threads active\000 */
{ 89641 }, /* tlb2_crste_writes\000cpum_cf\000extended\000TLB2 CRSTE Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000 */
{ 90845 }, /* tlb2_engines_busy\000cpum_cf\000extended\000TLB2 Engines Busy. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000The number of Level-2 TLB translation engines busy in a cycle\000 */
{ 91153 }, /* tlb2_pte_writes\000cpum_cf\000extended\000TLB2 PTE Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000 */
{ 92718 }, /* tx_c_tabort_no_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode not using special completion logic. Unit: cpum_cf \000event=0xf4\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 93893 }, /* tx_c_tabort_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf \000event=0xf5\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 94483 }, /* tx_c_tend\000cpum_cf\000extended\000Completed TEND instructions in constrained TX mode. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 95246 }, /* tx_nc_tabort\000cpum_cf\000extended\000Aborted transactions in non-constrained TX mode. Unit: cpum_cf \000event=0xf3\000\000\000\000\000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000 */
{ 95630 }, /* tx_nc_tend\000cpum_cf\000extended\000Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000 */
{ 97164 }, /* vx_bcd_execution_slots\000cpum_cf\000extended\000VX BCD Execution Slots. Unit: cpum_cf \000event=0xe1\000\000\000\000\000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMPVMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOPVCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVDVCVDG\000 */
};

static const struct compact_pmu_event pmu_metrics__cf_z15[] = {
{ 91977 }, /* transaction\000\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000Transaction count\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__cf_z16[] = {
{ 3351 }, /* cpu_cycles\000cpum_cf\000basic\000Cycle Count. Unit: cpum_cf \000event=0\000\000\000\000\000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 24736 }, /* instructions\000cpum_cf\000basic\000Instruction Count. Unit: cpum_cf \000event=0x1\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 44119 }, /* l1d_dir_writes\000cpum_cf\000basic\000Level-1 D-Cache Directory Write Count. Unit: cpum_cf \000event=0x4\000\000\000\000\000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 58432 }, /* l1d_penalty_cycles\000cpum_cf\000basic\000Level-1 D-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x5\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 60020 }, /* l1i_dir_writes\000cpum_cf\000basic\000Level-1 I-Cache Directory Write Count. Unit: cpum_cf \000event=0x2\000\000\000\000\000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 74491 }, /* l1i_penalty_cycles\000cpum_cf\000basic\000Level-1 I-Cache Penalty Cycle Count. Unit: cpum_cf \000event=0x3\000\000\000\000\000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 85129 }, /* problem_state_cpu_cycles\000cpum_cf\000basic\000Problem-State Cycle Count. Unit: cpum_cf \000event=0x20\000\000\000\000\000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 85381 }, /* problem_state_instructions\000cpum_cf\000basic\000Problem-State Instruction Count. Unit: cpum_cf \000event=0x21\000\000\000\000\000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 780 }, /* aes_blocked_cycles\000cpum_cf\000crypto6\000AES Blocked Cycle Count. Unit: cpum_cf \000event=0x4f\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 1327 }, /* aes_blocked_functions\000cpum_cf\000crypto6\000AES Blocked Function Count. Unit: cpum_cf \000event=0x4e\000\000\000\000\000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 1890 }, /* aes_cycles\000cpum_cf\000crypto6\000AES Cycle Count. Unit: cpum_cf \000event=0x4d\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 2309 }, /* aes_functions\000cpum_cf\000crypto6\000AES Function Count. Unit: cpum_cf \000event=0x4c\000\000\000\000\000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 7999 }, /* dea_blocked_cycles\000cpum_cf\000crypto6\000DEA Blocked Cycle Count. Unit: cpum_cf \000event=0x4b\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 8546 }, /* dea_blocked_functions\000cpum_cf\000crypto6\000DEA Blocked Function Count. Unit: cpum_cf \000event=0x4a\000\000\000\000\000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 9109 }, /* dea_cycles\000cpum_cf\000crypto6\000DEA Cycle Count. Unit: cpum_cf \000event=0x49\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 9528 }, /* dea_functions\000cpum_cf\000crypto6\000DEA Function Count. Unit: cpum_cf \000event=0x48\000\000\000\000\000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 15614 }, /* ecc_blocked_cycles_count\000cpum_cf\000crypto6\000ECC Blocked Cycles Count. Unit: cpum_cf \000event=0x53\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the elliptic-curve cryptography (ECC) functions issued by the CPU because the ECC coprocessor is busy performing a function issued by another CPU\000 */
{ 15921 }, /* ecc_blocked_function_count\000cpum_cf\000crypto6\000Ecc Blocked Function Count. Unit: cpum_cf \000event=0x52\000\000\000\000\000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions that are issued by the CPU and are blocked because the ECC coprocessor is busy performing a function issued by another CPU\000 */
{ 16234 }, /* ecc_cycles_count\000cpum_cf\000crypto6\000ECC Cycles Count. Unit: cpum_cf \000event=0x51\000\000\000\000\000\000This counter counts the total number of CPU cycles when the ECC coprocessor is busy performing the elliptic-curve cryptography (ECC) functions issued by the CPU\000 */
{ 16477 }, /* ecc_function_count\000cpum_cf\000crypto6\000ECC Function Count. Unit: cpum_cf \000event=0x50\000\000\000\000\000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions issued by the CPU\000 */
{ 82567 }, /* prng_blocked_cycles\000cpum_cf\000crypto6\000PRNG Blocked Cycle Count. Unit: cpum_cf \000event=0x43\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 83180 }, /* prng_blocked_functions\000cpum_cf\000crypto6\000PRNG Blocked Function Count. Unit: cpum_cf \000event=0x42\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 83809 }, /* prng_cycles\000cpum_cf\000crypto6\000PRNG Cycle Count. Unit: cpum_cf \000event=0x41\000\000\000\000\000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 84296 }, /* prng_functions\000cpum_cf\000crypto6\000PRNG Function Count. Unit: cpum_cf \000event=0x40\000\000\000\000\000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 86695 }, /* sha_blocked_cycles\000cpum_cf\000crypto6\000SHA Blocked Cycle Count. Unit: cpum_cf \000event=0x47\000\000\000\000\000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87234 }, /* sha_blocked_functions\000cpum_cf\000crypto6\000SHA Blocked Function Count. Unit: cpum_cf \000event=0x46\000\000\000\000\000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 87789 }, /* sha_cycles\000cpum_cf\000crypto6\000SHA Cycle Count. Unit: cpum_cf \000event=0x45\000\000\000\000\000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 88200 }, /* sha_functions\000cpum_cf\000crypto6\000SHA Function Count. Unit: cpum_cf \000event=0x44\000\000\000\000\000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 2874 }, /* bcd_dfp_execution_slots\000cpum_cf\000extended\000Binary Coded Decimal to Decimal Floating Point conversions. Unit: cpum_cf \000event=0xe0\000\000\000\000\000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000 */
{ 3535 }, /* crste_1mb_writes\000cpum_cf\000extended\000One Megabyte CRSTE writes. Unit: cpum_cf \000event=0x83\000\000\000\000\000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page\000 */
{ 3942 }, /* dcw_off_drawer\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Off-Drawer Cache. Unit: cpum_cf \000event=0x9b\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache\000 */
{ 4192 }, /* dcw_off_drawer_memory\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Off-Drawer Memory. Unit: cpum_cf \000event=0x9f\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 4440 }, /* dcw_on_chip\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Cache. Unit: cpum_cf \000event=0x95\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache\000 */
{ 4681 }, /* dcw_on_chip_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Cache with Chip HP Hit. Unit: cpum_cf \000event=0x97\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache after using chip level horizontal persistence, Chip-HP hit\000 */
{ 5007 }, /* dcw_on_chip_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Cache with Drawer HP Hit. Unit: cpum_cf \000event=0x98\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 5335 }, /* dcw_on_chip_iv\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Cache with Intervention. Unit: cpum_cf \000event=0x96\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache with intervention\000 */
{ 5615 }, /* dcw_on_chip_memory\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Chip Memory. Unit: cpum_cf \000event=0x9c\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 5854 }, /* dcw_on_drawer\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Drawer Cache. Unit: cpum_cf \000event=0x9a\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache\000 */
{ 6101 }, /* dcw_on_drawer_memory\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Drawer Memory. Unit: cpum_cf \000event=0x9e\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 6346 }, /* dcw_on_module\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Module Cache. Unit: cpum_cf \000event=0x99\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Module Level-2 cache\000 */
{ 6593 }, /* dcw_on_module_memory\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from On-Module Memory. Unit: cpum_cf \000event=0x9d\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Module memory\000 */
{ 6838 }, /* dcw_req\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Cache. Unit: cpum_cf \000event=0x91\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache\000 */
{ 7074 }, /* dcw_req_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Cache with Chip HP Hit. Unit: cpum_cf \000event=0x93\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache after using chip level horizontal persistence, Chip-HP hit\000 */
{ 7395 }, /* dcw_req_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Cache with Drawer HP Hit. Unit: cpum_cf \000event=0x94\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache after using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 7724 }, /* dcw_req_iv\000cpum_cf\000extended\000Directory Write Level 1 Data Cache from Cache with Intervention. Unit: cpum_cf \000event=0x92\000\000\000\000\000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestor’s Level-2 cache with intervention\000 */
{ 10028 }, /* decimal_instructions\000cpum_cf\000extended\000Decimal instruction dispatched. Unit: cpum_cf \000event=0xe2\000\000\000\000\000\000Decimal instruction dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000 */
{ 10385 }, /* dflt_access\000cpum_cf\000extended\000Cycles CPU spent obtaining access to Deflate unit. Unit: cpum_cf \000event=0xf8\000\000\000\000\000\000Cycles CPU spent obtaining access to Deflate unit\000 */
{ 10712 }, /* dflt_cc\000cpum_cf\000extended\000Increments DEFLATE CONVERSION CALL. Unit: cpum_cf \000event=0x109\000\000\000\000\000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed\000 */
{ 11110 }, /* dflt_ccfinish\000cpum_cf\000extended\000Increments completed DEFLATE CONVERSION CALL. Unit: cpum_cf \000event=0x10a\000\000\000\000\000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2\000 */
{ 11459 }, /* dflt_cycles\000cpum_cf\000extended\000Cycles CPU is using Deflate unit. Unit: cpum_cf \000event=0xfd\000\000\000\000\000\000Cycles CPU is using Deflate unit\000 */
{ 13752 }, /* dtlb2_gpage_writes\000cpum_cf\000extended\000DTLB2 Two-Gigabyte Page Writes. Unit: cpum_cf \000event=0x84\000\000\000\000\000\000A translation entry for a two-gigabyte page was written into the Level-2 TLB\000 */
{ 14422 }, /* dtlb2_misses\000cpum_cf\000extended\000DTLB2 Misses. Unit: cpum_cf \000event=0x82\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the Level-1 Data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on z13 and prior machines\000 */
{ 15054 }, /* dtlb2_writes\000cpum_cf\000extended\000DTLB2 Writes. Unit: cpum_cf \000event=0x81\000\000\000\000\000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the Level-1 Data cache. This is a replacement for what was provided for the DTLB on z13 and prior machines\000 */
{ 17312 }, /* icw_off_drawer\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Off-Drawer Cache. Unit: cpum_cf \000event=0xb3\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an Off-Drawer Level-2 cache\000 */
{ 17571 }, /* icw_off_drawer_memory\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Off-Drawer Memory. Unit: cpum_cf \000event=0xb7\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 17833 }, /* icw_on_chip\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Cache. Unit: cpum_cf \000event=0xad\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache\000 */
{ 18088 }, /* icw_on_chip_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Cache with Chip HP Hit. Unit: cpum_cf \000event=0xaf\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using chip level horizontal persistence, Chip-HP hit\000 */
{ 18422 }, /* icw_on_chip_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Cache with Drawer HP Hit. Unit: cpum_cf \000event=0xb0\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip level 2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 18764 }, /* icw_on_chip_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Cache with Intervention. Unit: cpum_cf \000event=0xae\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Chip Level-2 cache with intervention\000 */
{ 19053 }, /* icw_on_chip_memory\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Memory. Unit: cpum_cf \000event=0xb4\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 19306 }, /* icw_on_drawer\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Drawer Cache. Unit: cpum_cf \000event=0xb2\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Drawer Level-2 cache\000 */
{ 19562 }, /* icw_on_drawer_memory\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Drawer Memory. Unit: cpum_cf \000event=0xb6\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 19821 }, /* icw_on_module\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Module Cache. Unit: cpum_cf \000event=0xb1\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache\000 */
{ 20082 }, /* icw_on_module_memory\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from On-Module Memory. Unit: cpum_cf \000event=0xb5\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Module memory\000 */
{ 20341 }, /* icw_req\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Cache. Unit: cpum_cf \000event=0xa9\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced the requestors Level-2 cache\000 */
{ 20583 }, /* icw_req_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Cache with Chip HP Hit. Unit: cpum_cf \000event=0xab\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache using chip level horizontal persistence, Chip-HP hit\000 */
{ 20909 }, /* icw_req_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Cache with Drawer HP Hit. Unit: cpum_cf \000event=0xac\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestor’s Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 21246 }, /* icw_req_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction Cache from Cache with Intervention. Unit: cpum_cf \000event=0xaa\000\000\000\000\000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache with intervention\000 */
{ 21532 }, /* idcw_off_drawer_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer Cache with Chip Hit. Unit: cpum_cf \000event=0xa7\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit\000 */
{ 21898 }, /* idcw_off_drawer_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer Cache with Drawer Hit. Unit: cpum_cf \000event=0xa8\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 22272 }, /* idcw_off_drawer_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer Cache with Intervention. Unit: cpum_cf \000event=0xa6\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache with intervention\000 */
{ 22601 }, /* idcw_on_drawer_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer Cache with Chip Hit. Unit: cpum_cf \000event=0xa4\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit\000 */
{ 22964 }, /* idcw_on_drawer_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer Cache with Drawer Hit. Unit: cpum_cf \000event=0xa5\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 23335 }, /* idcw_on_drawer_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer Cache with Intervention. Unit: cpum_cf \000event=0xa3\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache with intervention\000 */
{ 23661 }, /* idcw_on_module_chip_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory Cache with Chip Hit. Unit: cpum_cf \000event=0xa1\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using chip horizontal persistence, Chip-HP hit\000 */
{ 24025 }, /* idcw_on_module_drawer_hit\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory Cache with Drawer Hit. Unit: cpum_cf \000event=0xa2\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 24403 }, /* idcw_on_module_iv\000cpum_cf\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory Cache with Intervention. Unit: cpum_cf \000event=0xa0\000\000\000\000\000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache with intervention\000 */
{ 26313 }, /* itlb2_misses\000cpum_cf\000extended\000ITLB2 Misses. Unit: cpum_cf \000event=0x87\000\000\000\000\000\000A TLB2 miss is in progress for a request made by the Level-1 Instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on z13 and prior machines\000 */
{ 27252 }, /* itlb2_writes\000cpum_cf\000extended\000ITLB2 Writes. Unit: cpum_cf \000event=0x86\000\000\000\000\000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on z13 and prior machines\000 */
{ 43949 }, /* l1c_tlb2_misses\000cpum_cf\000extended\000L1C TLB2 Misses. Unit: cpum_cf \000event=0x8f\000\000\000\000\000\000Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress\000 */
{ 58616 }, /* l1d_ro_excl_writes\000cpum_cf\000extended\000L1D Read-only Exclusive Writes. Unit: cpum_cf \000event=0x80\000\000\000\000\000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 75079 }, /* last_host_translations\000cpum_cf\000extended\000Last host translation done. Unit: cpum_cf \000event=0xe8\000\000\000\000\000\000Last Host Translation done\000 */
{ 75205 }, /* mt_diag_cycles_one_thr_active\000cpum_cf\000extended\000Cycle count with one thread active. Unit: cpum_cf \000event=0x1c0\000\000\000\000\000\000Cycle count with one thread active\000 */
{ 75355 }, /* mt_diag_cycles_two_thr_active\000cpum_cf\000extended\000Cycle count with two threads active. Unit: cpum_cf \000event=0x1c1\000\000\000\000\000\000Cycle count with two threads active\000 */
{ 75507 }, /* nnpa_completions\000cpum_cf\000extended\000NNPA Total completions. Unit: cpum_cf \000event=0x10c\000\000\000\000\000\000Increments by one for every Neural Network Processing Assist instruction executed that ended in Condition Codes 0, 1 or 2\000 */
{ 75719 }, /* nnpa_hold_lock\000cpum_cf\000extended\000Cycles spent holding NNPA lock. Unit: cpum_cf \000event=0x10e\000\000\000\000\000\000Cycles CPU is using IBM Z Integrated Accelerator for AI\000 */
{ 75871 }, /* nnpa_invocations\000cpum_cf\000extended\000NNPA Total invocations. Unit: cpum_cf \000event=0x10b\000\000\000\000\000\000Increments by one for every Neural Network Processing Assist instruction executed\000 */
{ 76043 }, /* nnpa_wait_lock\000cpum_cf\000extended\000Cycles spent obtaining NNPA lock. Unit: cpum_cf \000event=0x10d\000\000\000\000\000\000Cycles CPU spent obtaining access to IBM Z Integrated Accelerator for AI\000 */
{ 88513 }, /* sortl\000cpum_cf\000extended\000Count SORTL instructions. Unit: cpum_cf \000event=0x100\000\000\000\000\000\000Increments by one for every SORT LISTS instruction executed\000 */
{ 90594 }, /* tlb2_crste_writes\000cpum_cf\000extended\000TLB2 Combined Region and Segment Entry Writes. Unit: cpum_cf \000event=0x8a\000\000\000\000\000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000 */
{ 90845 }, /* tlb2_engines_busy\000cpum_cf\000extended\000TLB2 Engines Busy. Unit: cpum_cf \000event=0x8b\000\000\000\000\000\000The number of Level-2 TLB translation engines busy in a cycle\000 */
{ 91800 }, /* tlb2_pte_writes\000cpum_cf\000extended\000TLB2 Page Table Entry Writes. Unit: cpum_cf \000event=0x89\000\000\000\000\000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000 */
{ 93028 }, /* tx_c_tabort_no_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode. Unit: cpum_cf \000event=0xf5\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 94188 }, /* tx_c_tabort_special\000cpum_cf\000extended\000Aborted transactions in constrained TX mode using special completion logic. Unit: cpum_cf \000event=0xf6\000\000\000\000\000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 94483 }, /* tx_c_tend\000cpum_cf\000extended\000Completed TEND instructions in constrained TX mode. Unit: cpum_cf \000event=0x8c\000\000\000\000\000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 95439 }, /* tx_nc_tabort\000cpum_cf\000extended\000Aborted transactions in unconstrained TX mode. Unit: cpum_cf \000event=0xf4\000\000\000\000\000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000 */
{ 95630 }, /* tx_nc_tend\000cpum_cf\000extended\000Completed TEND instructions in non-constrained TX mode. Unit: cpum_cf \000event=0x8d\000\000\000\000\000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000 */
{ 96796 }, /* vx_bcd_execution_slots\000cpum_cf\000extended\000Count finished vector arithmetic Binary Coded Decimal instructions. Unit: cpum_cf \000event=0xe1\000\000\000\000\000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMP, VMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOP, VCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVD, VCVDG\000 */
{ 3757 }, /* crypto_all\000pai_crypto\000pai_crypto\000CRYPTO ALL. Unit: pai_crypto \000event=0x1000\000\000\000\000\000\000Sums of all non zero cryptography counters\000 */
{ 17020 }, /* ibm_reserved_155\000pai_crypto\000pai_crypto\000IBM RESERVED_155. Unit: pai_crypto \000event=0x109b\000\000\000\000\000\000Reserved for IBM use\000 */
{ 17134 }, /* ibm_reserved_156\000pai_crypto\000pai_crypto\000IBM RESERVED_156. Unit: pai_crypto \000event=0x109c\000\000\000\000\000\000Reserved for IBM use\000 */
{ 27545 }, /* kdsa_ecdsa_sign_p256\000pai_crypto\000pai_crypto\000KDSA ECDSA SIGN P256. Unit: pai_crypto \000event=0x1084\000\000\000\000\000\000KDSA-ECDSA-Sign-P256 function ending with CC=0\000 */
{ 27693 }, /* kdsa_ecdsa_sign_p384\000pai_crypto\000pai_crypto\000KDSA ECDSA SIGN P384. Unit: pai_crypto \000event=0x1085\000\000\000\000\000\000KDSA-ECDSA-Sign-P384 function ending with CC=0\000 */
{ 27841 }, /* kdsa_ecdsa_sign_p521\000pai_crypto\000pai_crypto\000KDSA ECDSA SIGN P521. Unit: pai_crypto \000event=0x1086\000\000\000\000\000\000KDSA-ECDSA-Sign-P521 function ending with CC=0\000 */
{ 27989 }, /* kdsa_ecdsa_verify_p256\000pai_crypto\000pai_crypto\000KDSA ECDSA VERIFY P256. Unit: pai_crypto \000event=0x1081\000\000\000\000\000\000KDSA-ECDSA-Verify-P256 function ending with CC=0 or CC=2\000 */
{ 28151 }, /* kdsa_ecdsa_verify_p384\000pai_crypto\000pai_crypto\000KDSA ECDSA VERIFY P384. Unit: pai_crypto \000event=0x1082\000\000\000\000\000\000KDSA-ECDSA-Verify-P384 function ending with CC=0 or CC=2\000 */
{ 28313 }, /* kdsa_ecdsa_verify_p521\000pai_crypto\000pai_crypto\000KDSA ECDSA VERIFY P521. Unit: pai_crypto \000event=0x1083\000\000\000\000\000\000KDSA-ECDSA-Verify-P521 function ending with CC=0 or CC=2\000 */
{ 28475 }, /* kdsa_eddsa_sign_ed25519\000pai_crypto\000pai_crypto\000KDSA EDDSA SIGN ED25519. Unit: pai_crypto \000event=0x108c\000\000\000\000\000\000KDSA-EdDSA-Sign-Ed25519 function ending with CC=0\000 */
{ 28632 }, /* kdsa_eddsa_sign_ed448\000pai_crypto\000pai_crypto\000KDSA EDDSA SIGN ED448. Unit: pai_crypto \000event=0x108d\000\000\000\000\000\000KDSA-EdDSA-Sign-Ed448 function ending with CC=0\000 */
{ 28783 }, /* kdsa_eddsa_verify_ed25519\000pai_crypto\000pai_crypto\000KDSA EDDSA VERIFY ED25519. Unit: pai_crypto \000event=0x108a\000\000\000\000\000\000KDSA-EdDSA-Verify-Ed25519 function ending with CC=0 or CC=2\000 */
{ 28954 }, /* kdsa_eddsa_verify_ed448\000pai_crypto\000pai_crypto\000KDSA EDDSA VERIFY ED448. Unit: pai_crypto \000event=0x108b\000\000\000\000\000\000KDSA-EdDSA-Verify-Ed448 function ending with CC=0 or CC=2\000 */
{ 29119 }, /* kdsa_encrypted_ecdsa_sign_p256\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P256. Unit: pai_crypto \000event=0x1087\000\000\000\000\000\000KDSA-Encrypted-ECDSA-Sign-P256 function ending with CC=0\000 */
{ 29297 }, /* kdsa_encrypted_ecdsa_sign_p384\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P384. Unit: pai_crypto \000event=0x1088\000\000\000\000\000\000KDSA-Encrypted-ECDSA-Sign-P384 function ending with CC=0\000 */
{ 29475 }, /* kdsa_encrypted_ecdsa_sign_p521\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P521. Unit: pai_crypto \000event=0x1089\000\000\000\000\000\000KDSA-Encrypted-ECDSA-Sign-P521 function ending with CC=0\000 */
{ 29653 }, /* kdsa_encrypted_eddsa_sign_ed25519\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED EDDSA SIGN ED25519. Unit: pai_crypto \000event=0x108e\000\000\000\000\000\000KDSA-Encrypted-EdDSA-Sign-Ed25519 function ending with CC=0\000 */
{ 29840 }, /* kdsa_encrypted_eddsa_sign_ed448\000pai_crypto\000pai_crypto\000KDSA ENCRYPTED EDDSA SIGN ED448. Unit: pai_crypto \000event=0x108f\000\000\000\000\000\000KDSA-Encrypted-EdDSA-Sign-Ed448 function ending with CC=0\000 */
{ 30021 }, /* kimd_ghash\000pai_crypto\000pai_crypto\000KIMD GHASH. Unit: pai_crypto \000event=0x1051\000\000\000\000\000\000KIMD-GHASH function ending with CC=0\000 */
{ 30139 }, /* kimd_sha3_224\000pai_crypto\000pai_crypto\000KIMD SHA3 224. Unit: pai_crypto \000event=0x104b\000\000\000\000\000\000KIMD-SHA3-224 function ending with CC=0\000 */
{ 30266 }, /* kimd_sha3_256\000pai_crypto\000pai_crypto\000KIMD SHA3 256. Unit: pai_crypto \000event=0x104c\000\000\000\000\000\000KIMD-SHA3-256 function ending with CC=0\000 */
{ 30393 }, /* kimd_sha3_384\000pai_crypto\000pai_crypto\000KIMD SHA3 384. Unit: pai_crypto \000event=0x104d\000\000\000\000\000\000KIMD-SHA3-384 function ending with CC=0\000 */
{ 30520 }, /* kimd_sha3_512\000pai_crypto\000pai_crypto\000KIMD SHA3 512. Unit: pai_crypto \000event=0x104e\000\000\000\000\000\000KIMD-SHA3-512 function ending with CC=0\000 */
{ 30647 }, /* kimd_sha_1\000pai_crypto\000pai_crypto\000KIMD SHA 1. Unit: pai_crypto \000event=0x1048\000\000\000\000\000\000KIMD-SHA-1 function ending with CC=0\000 */
{ 30765 }, /* kimd_sha_256\000pai_crypto\000pai_crypto\000KIMD SHA 256. Unit: pai_crypto \000event=0x1049\000\000\000\000\000\000KIMD-SHA-256 function ending with CC=0\000 */
{ 30889 }, /* kimd_sha_512\000pai_crypto\000pai_crypto\000KIMD SHA 512. Unit: pai_crypto \000event=0x104a\000\000\000\000\000\000KIMD-SHA-512 function ending with CC=0\000 */
{ 31013 }, /* kimd_shake_128\000pai_crypto\000pai_crypto\000KIMD SHAKE 128. Unit: pai_crypto \000event=0x104f\000\000\000\000\000\000KIMD-SHAKE-128 function ending with CC=0\000 */
{ 31143 }, /* kimd_shake_256\000pai_crypto\000pai_crypto\000KIMD SHAKE 256. Unit: pai_crypto \000event=0x1050\000\000\000\000\000\000KIMD-SHAKE-256 function ending with CC=0\000 */
{ 31273 }, /* klmd_sha3_224\000pai_crypto\000pai_crypto\000KLMD SHA3 224. Unit: pai_crypto \000event=0x1055\000\000\000\000\000\000KLMD-SHA3-224 function ending with CC=0\000 */
{ 31400 }, /* klmd_sha3_256\000pai_crypto\000pai_crypto\000KLMD SHA3 256. Unit: pai_crypto \000event=0x1056\000\000\000\000\000\000KLMD-SHA3-256 function ending with CC=0\000 */
{ 31527 }, /* klmd_sha3_384\000pai_crypto\000pai_crypto\000KLMD SHA3 384. Unit: pai_crypto \000event=0x1057\000\000\000\000\000\000KLMD-SHA3-384 function ending with CC=0\000 */
{ 31654 }, /* klmd_sha3_512\000pai_crypto\000pai_crypto\000KLMD SHA3 512. Unit: pai_crypto \000event=0x1058\000\000\000\000\000\000KLMD-SHA3-512 function ending with CC=0\000 */
{ 31781 }, /* klmd_sha_1\000pai_crypto\000pai_crypto\000KLMD SHA 1. Unit: pai_crypto \000event=0x1052\000\000\000\000\000\000KLMD-SHA-1 function ending with CC=0\000 */
{ 31899 }, /* klmd_sha_256\000pai_crypto\000pai_crypto\000KLMD SHA 256. Unit: pai_crypto \000event=0x1053\000\000\000\000\000\000KLMD-SHA-256 function ending with CC=0\000 */
{ 32023 }, /* klmd_sha_512\000pai_crypto\000pai_crypto\000KLMD SHA 512. Unit: pai_crypto \000event=0x1054\000\000\000\000\000\000KLMD-SHA-512 function ending with CC=0\000 */
{ 32147 }, /* klmd_shake_128\000pai_crypto\000pai_crypto\000KLMD SHAKE 128. Unit: pai_crypto \000event=0x1059\000\000\000\000\000\000KLMD-SHAKE-128 function ending with CC=0\000 */
{ 32277 }, /* klmd_shake_256\000pai_crypto\000pai_crypto\000KLMD SHAKE 256. Unit: pai_crypto \000event=0x105a\000\000\000\000\000\000KLMD-SHAKE-256 function ending with CC=0\000 */
{ 32407 }, /* km_aes_128\000pai_crypto\000pai_crypto\000KM AES 128. Unit: pai_crypto \000event=0x1007\000\000\000\000\000\000KM-AES-128 function ending with CC=0\000 */
{ 32525 }, /* km_aes_192\000pai_crypto\000pai_crypto\000KM AES 192. Unit: pai_crypto \000event=0x1008\000\000\000\000\000\000KM-AES-192 function ending with CC=0\000 */
{ 32643 }, /* km_aes_256\000pai_crypto\000pai_crypto\000KM AES 256. Unit: pai_crypto \000event=0x1009\000\000\000\000\000\000KM-AES-256 function ending with CC=0\000 */
{ 32761 }, /* km_dea\000pai_crypto\000pai_crypto\000KM DEA. Unit: pai_crypto \000event=0x1001\000\000\000\000\000\000KM-DEA function ending with CC=0\000 */
{ 32867 }, /* km_encrypted_aes_128\000pai_crypto\000pai_crypto\000KM ENCRYPTED AES 128. Unit: pai_crypto \000event=0x100a\000\000\000\000\000\000KM-Encrypted-AES-128 function ending with CC=0\000 */
{ 33015 }, /* km_encrypted_aes_192\000pai_crypto\000pai_crypto\000KM ENCRYPTED AES 192. Unit: pai_crypto \000event=0x100b\000\000\000\000\000\000KM-Encrypted-AES-192 function ending with CC=0\000 */
{ 33163 }, /* km_encrypted_aes_256\000pai_crypto\000pai_crypto\000KM ENCRYPTED AES 256. Unit: pai_crypto \000event=0x100c\000\000\000\000\000\000KM-Encrypted-AES-256 function ending with CC=0\000 */
{ 33311 }, /* km_encrypted_dea\000pai_crypto\000pai_crypto\000KM ENCRYPTED DEA. Unit: pai_crypto \000event=0x1004\000\000\000\000\000\000KM-Encrypted-DEA function ending with CC=0\000 */
{ 33447 }, /* km_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KM ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1005\000\000\000\000\000\000KM-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 33598 }, /* km_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KM ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1006\000\000\000\000\000\000KM-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 33749 }, /* km_tdea_128\000pai_crypto\000pai_crypto\000KM TDEA 128. Unit: pai_crypto \000event=0x1002\000\000\000\000\000\000KM-TDEA-128 function ending with CC=0\000 */
{ 33870 }, /* km_tdea_192\000pai_crypto\000pai_crypto\000KM TDEA 192. Unit: pai_crypto \000event=0x1003\000\000\000\000\000\000KM-TDEA-192 function ending with CC=0\000 */
{ 33991 }, /* km_xts_aes_128\000pai_crypto\000pai_crypto\000KM XTS AES 128. Unit: pai_crypto \000event=0x100d\000\000\000\000\000\000KM-XTS-AES-128 function ending with CC=0\000 */
{ 34121 }, /* km_xts_aes_256\000pai_crypto\000pai_crypto\000KM XTS AES 256. Unit: pai_crypto \000event=0x100e\000\000\000\000\000\000KM-XTS-AES-256 function ending with CC=0\000 */
{ 34251 }, /* km_xts_encrypted_aes_128\000pai_crypto\000pai_crypto\000KM XTS ENCRYPTED AES 128. Unit: pai_crypto \000event=0x100f\000\000\000\000\000\000KM-XTS-Encrypted-AES-128 function ending with CC=0\000 */
{ 34411 }, /* km_xts_encrypted_aes_256\000pai_crypto\000pai_crypto\000KM XTS ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1010\000\000\000\000\000\000KM-XTS-Encrypted-AES-256 function ending with CC=0\000 */
{ 34571 }, /* kma_gcm_aes_128\000pai_crypto\000pai_crypto\000KMA GCM AES 128. Unit: pai_crypto \000event=0x101e\000\000\000\000\000\000KMA-GCM-AES-128 function ending with CC=0\000 */
{ 34704 }, /* kma_gcm_aes_192\000pai_crypto\000pai_crypto\000KMA GCM AES 192. Unit: pai_crypto \000event=0x101f\000\000\000\000\000\000KMA-GCM-AES-192 function ending with CC=0\000 */
{ 34837 }, /* kma_gcm_aes_256\000pai_crypto\000pai_crypto\000KMA GCM AES 256. Unit: pai_crypto \000event=0x1020\000\000\000\000\000\000KMA-GCM-AES-256 function ending with CC=0\000 */
{ 34970 }, /* kma_gcm_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMA GCM ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1021\000\000\000\000\000\000KMA-GCM-Encrypted-AES-128 function ending with CC=0\000 */
{ 35133 }, /* kma_gcm_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMA GCM ENCRYPTED AES 192. Unit: pai_crypto \000event=0x1022\000\000\000\000\000\000KMA-GCM-Encrypted-AES-192 function ending with CC=0\000 */
{ 35296 }, /* kma_gcm_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMA GCM ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1023\000\000\000\000\000\000KMA-GCM-Encrypted-AES-256 function ending with CC=0\000 */
{ 35459 }, /* kmac_aes_128\000pai_crypto\000pai_crypto\000KMAC AES 128. Unit: pai_crypto \000event=0x1061\000\000\000\000\000\000KMAC-AES-128 function ending with CC=0\000 */
{ 35583 }, /* kmac_aes_192\000pai_crypto\000pai_crypto\000KMAC AES 192. Unit: pai_crypto \000event=0x1062\000\000\000\000\000\000KMAC-AES-192 function ending with CC=0\000 */
{ 35707 }, /* kmac_aes_256\000pai_crypto\000pai_crypto\000KMAC AES 256. Unit: pai_crypto \000event=0x1063\000\000\000\000\000\000KMAC-AES-256 function ending with CC=0\000 */
{ 35831 }, /* kmac_dea\000pai_crypto\000pai_crypto\000KMAC DEA. Unit: pai_crypto \000event=0x105b\000\000\000\000\000\000KMAC-DEA function ending with CC=0\000 */
{ 35943 }, /* kmac_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1064\000\000\000\000\000\000KMAC-Encrypted-AES-128 function ending with CC=0\000 */
{ 36097 }, /* kmac_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED AES 192. Unit: pai_crypto \000event=0x1065\000\000\000\000\000\000KMAC-Encrypted-AES-192 function ending with CC=0\000 */
{ 36251 }, /* kmac_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1066\000\000\000\000\000\000KMAC-Encrypted-AES-256 function ending with CC=0\000 */
{ 36405 }, /* kmac_encrypted_dea\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED DEA. Unit: pai_crypto \000event=0x105e\000\000\000\000\000\000KMAC-Encrypted-DEA function ending with CC=0\000 */
{ 36547 }, /* kmac_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x105f\000\000\000\000\000\000KMAC-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 36704 }, /* kmac_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMAC ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1060\000\000\000\000\000\000KMAC-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 36861 }, /* kmac_tdea_128\000pai_crypto\000pai_crypto\000KMAC TDEA 128. Unit: pai_crypto \000event=0x105c\000\000\000\000\000\000KMAC-TDEA-128 function ending with CC=0\000 */
{ 36988 }, /* kmac_tdea_192\000pai_crypto\000pai_crypto\000KMAC TDEA 192. Unit: pai_crypto \000event=0x105d\000\000\000\000\000\000KMAC-TDEA-192 function ending with CC=0\000 */
{ 37115 }, /* kmc_aes_128\000pai_crypto\000pai_crypto\000KMC AES 128. Unit: pai_crypto \000event=0x1017\000\000\000\000\000\000KMC-AES-128 function ending with CC=0\000 */
{ 37236 }, /* kmc_aes_192\000pai_crypto\000pai_crypto\000KMC AES 192. Unit: pai_crypto \000event=0x1018\000\000\000\000\000\000KMC-AES-192 function ending with CC=0\000 */
{ 37357 }, /* kmc_aes_256\000pai_crypto\000pai_crypto\000KMC AES 256. Unit: pai_crypto \000event=0x1019\000\000\000\000\000\000KMC-AES-256 function ending with CC=0\000 */
{ 37478 }, /* kmc_dea\000pai_crypto\000pai_crypto\000KMC DEA. Unit: pai_crypto \000event=0x1011\000\000\000\000\000\000KMC-DEA function ending with CC=0\000 */
{ 37587 }, /* kmc_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMC ENCRYPTED AES 128. Unit: pai_crypto \000event=0x101a\000\000\000\000\000\000KMC-Encrypted-AES-128 function ending with CC=0\000 */
{ 37738 }, /* kmc_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMC ENCRYPTED AES 192. Unit: pai_crypto \000event=0x101b\000\000\000\000\000\000KMC-Encrypted-AES-192 function ending with CC=0\000 */
{ 37889 }, /* kmc_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMC ENCRYPTED AES 256. Unit: pai_crypto \000event=0x101c\000\000\000\000\000\000KMC-Encrypted-AES-256 function ending with CC=0\000 */
{ 38040 }, /* kmc_encrypted_dea\000pai_crypto\000pai_crypto\000KMC ENCRYPTED DEA. Unit: pai_crypto \000event=0x1014\000\000\000\000\000\000KMC-Encrypted-DEA function ending with CC=0\000 */
{ 38179 }, /* kmc_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMC ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1015\000\000\000\000\000\000KMC-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 38333 }, /* kmc_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMC ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1016\000\000\000\000\000\000KMC-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 38487 }, /* kmc_prng\000pai_crypto\000pai_crypto\000KMC PRNG. Unit: pai_crypto \000event=0x101d\000\000\000\000\000\000KMC-PRNG function ending with CC=0\000 */
{ 38599 }, /* kmc_tdea_128\000pai_crypto\000pai_crypto\000KMC TDEA 128. Unit: pai_crypto \000event=0x1012\000\000\000\000\000\000KMC-TDEA-128 function ending with CC=0\000 */
{ 38723 }, /* kmc_tdea_192\000pai_crypto\000pai_crypto\000KMC TDEA 192. Unit: pai_crypto \000event=0x1013\000\000\000\000\000\000KMC-TDEA-192 function ending with CC=0\000 */
{ 38847 }, /* kmctr_aes_128\000pai_crypto\000pai_crypto\000KMCTR AES 128. Unit: pai_crypto \000event=0x1036\000\000\000\000\000\000KMCTR-AES-128 function ending with CC=0\000 */
{ 38974 }, /* kmctr_aes_192\000pai_crypto\000pai_crypto\000KMCTR AES 192. Unit: pai_crypto \000event=0x1037\000\000\000\000\000\000KMCTR-AES-192 function ending with CC=0\000 */
{ 39101 }, /* kmctr_aes_256\000pai_crypto\000pai_crypto\000KMCTR AES 256. Unit: pai_crypto \000event=0x1038\000\000\000\000\000\000KMCTR-AES-256 function ending with CC=0\000 */
{ 39228 }, /* kmctr_dea\000pai_crypto\000pai_crypto\000KMCTR DEA. Unit: pai_crypto \000event=0x1030\000\000\000\000\000\000KMCTR-DEA function ending with CC=0\000 */
{ 39343 }, /* kmctr_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1039\000\000\000\000\000\000KMCTR-Encrypted-AES-128 function ending with CC=0\000 */
{ 39500 }, /* kmctr_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED AES 192. Unit: pai_crypto \000event=0x103a\000\000\000\000\000\000KMCTR-Encrypted-AES-192 function ending with CC=0\000 */
{ 39657 }, /* kmctr_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED AES 256. Unit: pai_crypto \000event=0x103b\000\000\000\000\000\000KMCTR-Encrypted-AES-256 function ending with CC=0\000 */
{ 39814 }, /* kmctr_encrypted_dea\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED DEA. Unit: pai_crypto \000event=0x1033\000\000\000\000\000\000KMCTR-Encrypted-DEA function ending with CC=0\000 */
{ 39959 }, /* kmctr_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1034\000\000\000\000\000\000KMCTR-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 40119 }, /* kmctr_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMCTR ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1035\000\000\000\000\000\000KMCTR-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 40279 }, /* kmctr_tdea_128\000pai_crypto\000pai_crypto\000KMCTR TDEA 128. Unit: pai_crypto \000event=0x1031\000\000\000\000\000\000KMCTR-TDEA-128 function ending with CC=0\000 */
{ 40409 }, /* kmctr_tdea_192\000pai_crypto\000pai_crypto\000KMCTR TDEA 192. Unit: pai_crypto \000event=0x1032\000\000\000\000\000\000KMCTR-TDEA-192 function ending with CC=0\000 */
{ 40539 }, /* kmf_aes_128\000pai_crypto\000pai_crypto\000KMF AES 128. Unit: pai_crypto \000event=0x102a\000\000\000\000\000\000KMF-AES-128 function ending with CC=0\000 */
{ 40660 }, /* kmf_aes_192\000pai_crypto\000pai_crypto\000KMF AES 192. Unit: pai_crypto \000event=0x102b\000\000\000\000\000\000KMF-AES-192 function ending with CC=0\000 */
{ 40781 }, /* kmf_aes_256\000pai_crypto\000pai_crypto\000KMF AES 256. Unit: pai_crypto \000event=0x102c\000\000\000\000\000\000KMF-AES-256 function ending with CC=0\000 */
{ 40902 }, /* kmf_dea\000pai_crypto\000pai_crypto\000KMF DEA. Unit: pai_crypto \000event=0x1024\000\000\000\000\000\000KMF-DEA function ending with CC=0\000 */
{ 41011 }, /* kmf_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMF ENCRYPTED AES 128. Unit: pai_crypto \000event=0x102d\000\000\000\000\000\000KMF-Encrypted-AES-128 function ending with CC=0\000 */
{ 41162 }, /* kmf_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMF ENCRYPTED AES 192. Unit: pai_crypto \000event=0x102e\000\000\000\000\000\000KMF-Encrypted-AES-192 function ending with CC=0\000 */
{ 41313 }, /* kmf_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMF ENCRYPTED AES 256. Unit: pai_crypto \000event=0x102f\000\000\000\000\000\000KMF-Encrypted-AES-256 function ending with CC=0\000 */
{ 41464 }, /* kmf_encrypted_dea\000pai_crypto\000pai_crypto\000KMF ENCRYPTED DEA. Unit: pai_crypto \000event=0x1027\000\000\000\000\000\000KMF-Encrypted-DEA function ending with CC=0\000 */
{ 41603 }, /* kmf_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMF ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1028\000\000\000\000\000\000KMF-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 41757 }, /* kmf_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMF ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1029\000\000\000\000\000\000KMF-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 41911 }, /* kmf_tdea_128\000pai_crypto\000pai_crypto\000KMF TDEA 128. Unit: pai_crypto \000event=0x1025\000\000\000\000\000\000KMF-TDEA-128 function ending with CC=0\000 */
{ 42035 }, /* kmf_tdea_192\000pai_crypto\000pai_crypto\000KMF TDEA 192. Unit: pai_crypto \000event=0x1026\000\000\000\000\000\000KMF-TDEA-192 function ending with CC=0\000 */
{ 42159 }, /* kmo_aes_128\000pai_crypto\000pai_crypto\000KMO AES 128. Unit: pai_crypto \000event=0x1042\000\000\000\000\000\000KMO-AES-128 function ending with CC=0\000 */
{ 42280 }, /* kmo_aes_192\000pai_crypto\000pai_crypto\000KMO AES 192. Unit: pai_crypto \000event=0x1043\000\000\000\000\000\000KMO-AES-192 function ending with CC=0\000 */
{ 42401 }, /* kmo_aes_256\000pai_crypto\000pai_crypto\000KMO AES 256. Unit: pai_crypto \000event=0x1044\000\000\000\000\000\000KMO-AES-256 function ending with CC=0\000 */
{ 42522 }, /* kmo_dea\000pai_crypto\000pai_crypto\000KMO DEA. Unit: pai_crypto \000event=0x103c\000\000\000\000\000\000KMO-DEA function ending with CC=0\000 */
{ 42631 }, /* kmo_encrypted_aes_128\000pai_crypto\000pai_crypto\000KMO ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1045\000\000\000\000\000\000KMO-Encrypted-AES-128 function ending with CC=0\000 */
{ 42782 }, /* kmo_encrypted_aes_192\000pai_crypto\000pai_crypto\000KMO ENCRYPTED AES 192. Unit: pai_crypto \000event=0x1046\000\000\000\000\000\000KMO-Encrypted-AES-192 function ending with CC=0\000 */
{ 42933 }, /* kmo_encrypted_aes_256\000pai_crypto\000pai_crypto\000KMO ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1047\000\000\000\000\000\000KMO-Encrypted-AES-256 function ending with CC=0\000 */
{ 43084 }, /* kmo_encrypted_dea\000pai_crypto\000pai_crypto\000KMO ENCRYPTED DEA. Unit: pai_crypto \000event=0x103f\000\000\000\000\000\000KMO-Encrypted-DEA function ending with CC=0\000 */
{ 43223 }, /* kmo_encrypted_tdea_128\000pai_crypto\000pai_crypto\000KMO ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x1040\000\000\000\000\000\000KMO-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 43377 }, /* kmo_encrypted_tdea_192\000pai_crypto\000pai_crypto\000KMO ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x1041\000\000\000\000\000\000KMO-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 43531 }, /* kmo_tdea_128\000pai_crypto\000pai_crypto\000KMO TDEA 128. Unit: pai_crypto \000event=0x103d\000\000\000\000\000\000KMO-TDEA-128 function ending with CC=0\000 */
{ 43655 }, /* kmo_tdea_192\000pai_crypto\000pai_crypto\000KMO TDEA 192. Unit: pai_crypto \000event=0x103e\000\000\000\000\000\000KMO-TDEA-192 function ending with CC=0\000 */
{ 76214 }, /* pcc_compute_last_block_cmac_using_aes_128\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 128. Unit: pai_crypto \000event=0x106d\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-AES-128 function ending with CC=0\000 */
{ 76425 }, /* pcc_compute_last_block_cmac_using_aes_192\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 192. Unit: pai_crypto \000event=0x106e\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-AES-192 function ending with CC=0\000 */
{ 76636 }, /* pcc_compute_last_block_cmac_using_aes_256\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 256. Unit: pai_crypto \000event=0x106f\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-AES-256 function ending with CC=0\000 */
{ 76847 }, /* pcc_compute_last_block_cmac_using_dea\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING DEA. Unit: pai_crypto \000event=0x1067\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-DEA function ending with CC=0\000 */
{ 77046 }, /* pcc_compute_last_block_cmac_using_encrypted_aes_128\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1070\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 128 function ending with CC=0\000 */
{ 77288 }, /* pcc_compute_last_block_cmac_using_encrypted_aes_192\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 192. Unit: pai_crypto \000event=0x1071\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 192 function ending with CC=0\000 */
{ 77530 }, /* pcc_compute_last_block_cmac_using_encrypted_aes_256a\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 256A. Unit: pai_crypto \000event=0x1072\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 256A function ending with CC=0\000 */
{ 77775 }, /* pcc_compute_last_block_cmac_using_encrypted_dea\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED DEA. Unit: pai_crypto \000event=0x106a\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-DEA function ending with CC=0\000 */
{ 78004 }, /* pcc_compute_last_block_cmac_using_encrypted_tdea_128\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED TDEA 128. Unit: pai_crypto \000event=0x106b\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-TDEA- 128 function ending with CC=0\000 */
{ 78249 }, /* pcc_compute_last_block_cmac_using_encrypted_tdea_192\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED TDEA 192. Unit: pai_crypto \000event=0x106c\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-TDEA- 192 function ending with CC=0\000 */
{ 78494 }, /* pcc_compute_last_block_cmac_using_tdea_128\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING TDEA 128. Unit: pai_crypto \000event=0x1068\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-TDEA-128 function ending with CC=0\000 */
{ 78708 }, /* pcc_compute_last_block_cmac_using_tdea_192\000pai_crypto\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING TDEA 192. Unit: pai_crypto \000event=0x1069\000\000\000\000\000\000PCC-Compute-Last-Block-CMAC-Using-TDEA-192 function ending with CC=0\000 */
{ 78922 }, /* pcc_compute_xts_parameter_using_aes_128\000pai_crypto\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING AES 128. Unit: pai_crypto \000event=0x1073\000\000\000\000\000\000PCC-Compute-XTS-Parameter-Using-AES-128 function ending with CC=0\000 */
{ 79127 }, /* pcc_compute_xts_parameter_using_aes_256\000pai_crypto\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING AES 256. Unit: pai_crypto \000event=0x1074\000\000\000\000\000\000PCC-Compute-XTS-Parameter-Using-AES-256 function ending with CC=0\000 */
{ 79332 }, /* pcc_compute_xts_parameter_using_encrypted_aes_128\000pai_crypto\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING ENCRYPTED AES 128. Unit: pai_crypto \000event=0x1075\000\000\000\000\000\000PCC-Compute-XTS-Parameter-Using-Encrypted-AES-128 function ending with CC=0\000 */
{ 79567 }, /* pcc_compute_xts_parameter_using_encrypted_aes_256\000pai_crypto\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING ENCRYPTED AES 256. Unit: pai_crypto \000event=0x1076\000\000\000\000\000\000PCC-Compute-XTS-Parameter-Using-Encrypted-AES-256 function ending with CC=0\000 */
{ 79802 }, /* pcc_scalar_multiply_ed25519\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY ED25519. Unit: pai_crypto \000event=0x107a\000\000\000\000\000\000PCC-Scalar-Multiply-Ed25519 function ending with CC=0\000 */
{ 79971 }, /* pcc_scalar_multiply_ed448\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY ED448. Unit: pai_crypto \000event=0x107b\000\000\000\000\000\000PCC-Scalar-Multiply-Ed448 function ending with CC=0\000 */
{ 80134 }, /* pcc_scalar_multiply_p256\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY P256. Unit: pai_crypto \000event=0x1077\000\000\000\000\000\000PCC-Scalar-Multiply-P256 function ending with CC=0\000 */
{ 80294 }, /* pcc_scalar_multiply_p384\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY P384. Unit: pai_crypto \000event=0x1078\000\000\000\000\000\000PCC-Scalar-Multiply-P384 function ending with CC=0\000 */
{ 80454 }, /* pcc_scalar_multiply_p521\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY P521. Unit: pai_crypto \000event=0x1079\000\000\000\000\000\000PCC-Scalar-Multiply-P521 function ending with CC=0\000 */
{ 80614 }, /* pcc_scalar_multiply_x25519\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY X25519. Unit: pai_crypto \000event=0x107c\000\000\000\000\000\000PCC-Scalar-Multiply-X25519 function ending with CC=0\000 */
{ 80780 }, /* pcc_scalar_multiply_x448\000pai_crypto\000pai_crypto\000PCC SCALAR MULTIPLY X448. Unit: pai_crypto \000event=0x107d\000\000\000\000\000\000PCC-Scalar-Multiply-X448 function ending with CC=0\000 */
{ 80940 }, /* pckmo_encrypt_aes_128_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT AES 128 KEY. Unit: pai_crypto \000event=0x1093\000\000\000\000\000\000PCKMO-Encrypt-AES-128-key function\000 */
{ 81086 }, /* pckmo_encrypt_aes_192_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT AES 192 KEY. Unit: pai_crypto \000event=0x1094\000\000\000\000\000\000PCKMO-Encrypt-AES-192-key function\000 */
{ 81232 }, /* pckmo_encrypt_aes_256_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT AES 256 KEY. Unit: pai_crypto \000event=0x1095\000\000\000\000\000\000PCKMO-Encrypt-AES-256-key function\000 */
{ 81378 }, /* pckmo_encrypt_dea_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT DEA KEY. Unit: pai_crypto \000event=0x1090\000\000\000\000\000\000PCKMO-Encrypt-DEA-key function\000 */
{ 81512 }, /* pckmo_encrypt_ecc_ed25519_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC ED25519 KEY. Unit: pai_crypto \000event=0x1099\000\000\000\000\000\000PCKMO-Encrypt-ECC-Ed25519-key function\000 */
{ 81670 }, /* pckmo_encrypt_ecc_ed448_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC ED448 KEY. Unit: pai_crypto \000event=0x109a\000\000\000\000\000\000PCKMO-Encrypt-ECC-Ed448-key function\000 */
{ 81822 }, /* pckmo_encrypt_ecc_p256_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC P256 KEY. Unit: pai_crypto \000event=0x1096\000\000\000\000\000\000PCKMO-Encrypt-ECC-P256-key function\000 */
{ 81971 }, /* pckmo_encrypt_ecc_p384_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC P384 KEY. Unit: pai_crypto \000event=0x1097\000\000\000\000\000\000PCKMO-Encrypt-ECC-P384-key function\000 */
{ 82120 }, /* pckmo_encrypt_ecc_p521_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT ECC P521 KEY. Unit: pai_crypto \000event=0x1098\000\000\000\000\000\000PCKMO-Encrypt-ECC-P521-key function\000 */
{ 82269 }, /* pckmo_encrypt_tdea_128_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT TDEA 128 KEY. Unit: pai_crypto \000event=0x1091\000\000\000\000\000\000PCKMO-Encrypt-TDEA-128-key function\000 */
{ 82418 }, /* pckmo_encrypt_tdea_192_key\000pai_crypto\000pai_crypto\000PCKMO ENCRYPT TDEA 192 KEY. Unit: pai_crypto \000event=0x1092\000\000\000\000\000\000PCKMO-Encrypt-TDEA-192-key function\000 */
{ 84667 }, /* prno_sha_512_drng\000pai_crypto\000pai_crypto\000PRNO SHA 512 DRNG. Unit: pai_crypto \000event=0x107e\000\000\000\000\000\000PRNO-SHA-512-DRNG function ending with CC=0\000 */
{ 84806 }, /* prno_trng\000pai_crypto\000pai_crypto\000PRNO TRNG. Unit: pai_crypto \000event=0x1080\000\000\000\000\000\000PRNO-TRNG function ending with CC=0\000 */
{ 84921 }, /* prno_trng_query_raw_to_conditioned_ratio\000pai_crypto\000pai_crypto\000PRNO TRNG QUERY RAW TO CONDITIONED RATIO. Unit: pai_crypto \000event=0x107f\000\000\000\000\000\000PRNO-TRNG-Query-Raw-to-Conditioned-Ratio function ending with CC=0\000 */
};

static const struct compact_pmu_event pmu_metrics__cf_z16[] = {
{ 91977 }, /* transaction\000\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000Transaction count\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__test_soc_cpu[] = {
{ 3161 }, /* bp_l1_btb_correct\000\000branch\000L1 BTB Correction\000event=0x8a\000\000\000\000\000\000\000 */
{ 3222 }, /* bp_l2_btb_correct\000\000branch\000L2 BTB Correction\000event=0x8b\000\000\000\000\000\000\000 */
{ 74982 }, /* l3_cache_rd\000\000cache\000L3 cache access, read\000event=0x40\000\000\000\000\000\000Attributable Level 3 cache access, read\000 */
{ 11586 }, /* dispatch_blocked.any\000\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=0x9,period=200000,umask=0x20\000\000\000\000\000\000\000 */
{ 16669 }, /* eist_trans\000\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000,umask=0x0\000\000\000\000\000\000\000 */
{ 86592 }, /* segment_reg_loads.any\000\000other\000Number of segment register loads\000event=0x6,period=200000,umask=0x80\000\000\000\000\000\000\000 */
{ 16796 }, /* event-hyphen\000uncore_cbox\000uncore\000UNC_CBO_HYPHEN. Unit: uncore_cbox \000event=0xe0,umask=0x00\000\000\000\000\000\000UNC_CBO_HYPHEN\000 */
{ 16905 }, /* event-two-hyph\000uncore_cbox\000uncore\000UNC_CBO_TWO_HYPH. Unit: uncore_cbox \000event=0xc0,umask=0x00\000\000\000\000\000\000UNC_CBO_TWO_HYPH\000 */
{ 96025 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore_cbox\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core. Unit: uncore_cbox \000event=0x22,umask=0x81\000\000\000\000\000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000 */
{ 96289 }, /* uncore_hisi_ddrc.flux_wcmd\000hisi_sccl,ddrc\000uncore\000DDRC write commands. Unit: hisi_sccl,ddrc \000event=0x2\000\000\000\000\000\000DDRC write commands\000 */
{ 96416 }, /* uncore_hisi_l3c.rd_hit_cpipe\000hisi_sccl,l3c\000uncore\000Total read hits. Unit: hisi_sccl,l3c \000event=0x7\000\000\000\000\000\000Total read hits\000 */
{ 96535 }, /* uncore_imc.cache_hits\000uncore_imc\000uncore\000Total cache hits. Unit: uncore_imc \000event=0x34\000\000\000\000\000\000Total cache hits\000 */
{ 96644 }, /* uncore_imc_free_running.cache_miss\000uncore_imc_free_running\000uncore\000Total cache misses. Unit: uncore_imc_free_running \000event=0x12\000\000\000\000\000\000Total cache misses\000 */
};

static const struct compact_pmu_event pmu_metrics__test_soc_cpu[] = {
{ 0 }, /* CPI\000\000\0001 / IPC\000\000\000\000\000\000 */
{ 19 }, /* DCache_L2_All\000\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000 */
{ 80 }, /* DCache_L2_All_Hits\000\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000 */
{ 171 }, /* DCache_L2_All_Miss\000\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000 */
{ 302 }, /* DCache_L2_Hits\000\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000 */
{ 367 }, /* DCache_L2_Misses\000\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000 */
{ 434 }, /* Frontend_Bound_SMT\000\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000 */
{ 597 }, /* IPC\000group1\000\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000 */
{ 657 }, /* L1D_Cache_Fill_BW\000\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000 */
{ 725 }, /* M1\000\000\000ipc + M2\000\000\000\000\000\000 */
{ 744 }, /* M2\000\000\000ipc + M1\000\000\000\000\000\000 */
{ 763 }, /* M3\000\000\0001 / M3\000\000\000\000\000\000 */
{ 3283 }, /* cache_miss_cycles\000group1\000\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000 */
{ 3881 }, /* dcache_miss_cpi\000\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000 */
{ 17248 }, /* icache_miss_cycles\000\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000 */
};

static const struct compact_pmu_event pmu_events__test_soc_sys[] = {
{ 88654 }, /* sys_ccn_pmu.read_cycles\000uncore_sys_ccn_pmu\000uncore\000ccn read-cycles event. Unit: uncore_sys_ccn_pmu \000config=0x2c\000\0000x01\000\000\000\000\000 */
{ 88775 }, /* sys_ddr_pmu.write_cycles\000uncore_sys_ddr_pmu\000uncore\000ddr write-cycles event. Unit: uncore_sys_ddr_pmu \000event=0x2b\000\000v8\000\000\000\000\000 */
};


/* Struct used to make the PMU event table implementation opaque to callers. */
struct pmu_events_table {
        const struct compact_pmu_event *entries;
        size_t length;
};

/* Struct used to make the PMU metric table implementation opaque to callers. */
struct pmu_metrics_table {
        const struct compact_pmu_event *entries;
        size_t length;
};

/*
 * Map a CPU to its table of PMU events. The CPU is identified by the
 * cpuid field, which is an arch-specific identifier for the CPU.
 * The identifier specified in tools/perf/pmu-events/arch/xxx/mapfile
 * must match the get_cpuid_str() in tools/perf/arch/xxx/util/header.c)
 *
 * The  cpuid can contain any character other than the comma.
 */
struct pmu_events_map {
        const char *arch;
        const char *cpuid;
        struct pmu_events_table event_table;
        struct pmu_metrics_table metric_table;
};

/*
 * Global table mapping each known CPU for the architecture to its
 * table of PMU events.
 */
const struct pmu_events_map pmu_events_map[] = {
{
	.arch = "s390",
	.cpuid = "^IBM.209[78].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.entries = pmu_events__cf_z10,
		.length = ARRAY_SIZE(pmu_events__cf_z10)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.281[78].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.entries = pmu_events__cf_z196,
		.length = ARRAY_SIZE(pmu_events__cf_z196)
	},
	.metric_table = {
		.entries = NULL,
		.length = 0
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.282[78].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.entries = pmu_events__cf_zec12,
		.length = ARRAY_SIZE(pmu_events__cf_zec12)
	},
	.metric_table = {
		.entries = pmu_metrics__cf_zec12,
		.length = ARRAY_SIZE(pmu_metrics__cf_zec12)
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.296[45].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.entries = pmu_events__cf_z13,
		.length = ARRAY_SIZE(pmu_events__cf_z13)
	},
	.metric_table = {
		.entries = pmu_metrics__cf_z13,
		.length = ARRAY_SIZE(pmu_metrics__cf_z13)
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.390[67].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.entries = pmu_events__cf_z14,
		.length = ARRAY_SIZE(pmu_events__cf_z14)
	},
	.metric_table = {
		.entries = pmu_metrics__cf_z14,
		.length = ARRAY_SIZE(pmu_metrics__cf_z14)
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.856[12].*3\\.6.[[:xdigit:]]+$",
	.event_table = {
		.entries = pmu_events__cf_z15,
		.length = ARRAY_SIZE(pmu_events__cf_z15)
	},
	.metric_table = {
		.entries = pmu_metrics__cf_z15,
		.length = ARRAY_SIZE(pmu_metrics__cf_z15)
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.393[12].*3\\.7.[[:xdigit:]]+$",
	.event_table = {
		.entries = pmu_events__cf_z16,
		.length = ARRAY_SIZE(pmu_events__cf_z16)
	},
	.metric_table = {
		.entries = pmu_metrics__cf_z16,
		.length = ARRAY_SIZE(pmu_metrics__cf_z16)
	}
},
{
	.arch = "testarch",
	.cpuid = "testcpu",
	.event_table = {
		.entries = pmu_events__test_soc_cpu,
		.length = ARRAY_SIZE(pmu_events__test_soc_cpu),
	},
	.metric_table = {
		.entries = pmu_metrics__test_soc_cpu,
		.length = ARRAY_SIZE(pmu_metrics__test_soc_cpu),
	}
},
{
	.arch = 0,
	.cpuid = 0,
	.event_table = { 0, 0 },
	.metric_table = { 0, 0 },
}
};

struct pmu_sys_events {
	const char *name;
	struct pmu_events_table event_table;
	struct pmu_metrics_table metric_table;
};

static const struct pmu_sys_events pmu_sys_event_tables[] = {
	{
		.event_table = {
			.entries = pmu_events__test_soc_sys,
			.length = ARRAY_SIZE(pmu_events__test_soc_sys)
		},
		.name = "pmu_events__test_soc_sys",
	},
	{
		.event_table = { 0, 0 },
		.metric_table = { 0, 0 },
	},
};

static void decompress_event(int offset, struct pmu_event *pe)
{
	const char *p = &big_c_string[offset];

	pe->name = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->pmu = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->topic = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->event = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->aggr_mode = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->deprecated = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->perpkg = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->long_desc = (*p == '\0' ? NULL : p);
}

static void decompress_metric(int offset, struct pmu_metric *pm)
{
	const char *p = &big_c_string[offset];

	pm->metric_name = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_group = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_constraint = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_expr = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->long_desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->aggr_mode = (*p == '\0' ? NULL : p);
}

int pmu_events_table_for_each_event(const struct pmu_events_table *table,
                                    pmu_event_iter_fn fn,
                                    void *data)
{
        for (size_t i = 0; i < table->length; i++) {
                struct pmu_event pe;
                int ret;

                decompress_event(table->entries[i].offset, &pe);
                if (!pe.name)
                        continue;
                ret = fn(&pe, table, data);
                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_metrics_table_for_each_metric(const struct pmu_metrics_table *table,
                                     pmu_metric_iter_fn fn,
                                     void *data)
{
        for (size_t i = 0; i < table->length; i++) {
                struct pmu_metric pm;
                int ret;

                decompress_metric(table->entries[i].offset, &pm);
                if (!pm.metric_expr)
                        continue;
                ret = fn(&pm, table, data);
                if (ret)
                        return ret;
        }
        return 0;
}

const struct pmu_events_table *perf_pmu__find_events_table(struct perf_pmu *pmu)
{
        const struct pmu_events_table *table = NULL;
        char *cpuid = perf_pmu__getcpuid(pmu);
        int i;

        /* on some platforms which uses cpus map, cpuid can be NULL for
         * PMUs other than CORE PMUs.
         */
        if (!cpuid)
                return NULL;

        i = 0;
        for (;;) {
                const struct pmu_events_map *map = &pmu_events_map[i++];
                if (!map->arch)
                        break;

                if (!strcmp_cpuid_str(map->cpuid, cpuid)) {
                        table = &map->event_table;
                        break;
                }
        }
        free(cpuid);
        return table;
}

const struct pmu_metrics_table *perf_pmu__find_metrics_table(struct perf_pmu *pmu)
{
        const struct pmu_metrics_table *table = NULL;
        char *cpuid = perf_pmu__getcpuid(pmu);
        int i;

        /* on some platforms which uses cpus map, cpuid can be NULL for
         * PMUs other than CORE PMUs.
         */
        if (!cpuid)
                return NULL;

        i = 0;
        for (;;) {
                const struct pmu_events_map *map = &pmu_events_map[i++];
                if (!map->arch)
                        break;

                if (!strcmp_cpuid_str(map->cpuid, cpuid)) {
                        table = &map->metric_table;
                        break;
                }
        }
        free(cpuid);
        return table;
}

const struct pmu_events_table *find_core_events_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->event_table;
        }
        return NULL;
}

const struct pmu_metrics_table *find_core_metrics_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->metric_table;
        }
        return NULL;
}

int pmu_for_each_core_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_events_table_for_each_event(&tables->event_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_core_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_metrics_table_for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

const struct pmu_events_table *find_sys_events_table(const char *name)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                if (!strcmp(tables->name, name))
                        return &tables->event_table;
        }
        return NULL;
}

int pmu_for_each_sys_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_events_table_for_each_event(&tables->event_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_sys_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_metrics_table_for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}
